# clientapi_atrocore
This is a REST API documentation for AtroCore data platform and its modules (AtroPIM, AtroDAM and others), which is based on [OpenAPI (Swagger) Specification](https://swagger.io/specification/). You can generate your client [here](https://openapi-generator.tech/docs/generators).<br><br><h3>Video tutorials:</h3><ul><li>[How to authorize?](https://youtu.be/GWfNRvCswXg)</li><li>[How to select specific fields?](https://youtu.be/i7o0aENuyuY)</li><li>[How to filter data records?](https://youtu.be/irgWkN4wlkM)</li></ul>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.55
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
# from pypi
pip install clientapi_atrocore

# from source
pip install git+https://github.com/client-api/atrocore-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/client-api/atrocore-python.git`)

Then import the package:
```python
import clientapi_atrocore
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import clientapi_atrocore
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import clientapi_atrocore
from clientapi_atrocore.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://demo.atropim.com/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = clientapi_atrocore.Configuration(
    host = "https://demo.atropim.com/api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: Authorization-Token
configuration.api_key['Authorization-Token'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization-Token'] = 'Bearer'


# Enter a context with an instance of the API client
with clientapi_atrocore.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = clientapi_atrocore.AccountApi(api_client)
    link = 'link_example' # str | 
    ids = ['ids_example'] # List[str] | 
    foreign_ids = ['foreign_ids_example'] # List[str] | 

    try:
        # Add relation for Account
        api_response = api_instance.add_relation_for_account(link, ids, foreign_ids)
        print("The response of AccountApi->add_relation_for_account:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountApi->add_relation_for_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://demo.atropim.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**add_relation_for_account**](docs/AccountApi.md#add_relation_for_account) | **POST** /Account/{link}/relation | Add relation for Account
*AccountApi* | [**create_account_item**](docs/AccountApi.md#create_account_item) | **POST** /Account | Create a record of the Account
*AccountApi* | [**delete_account_item**](docs/AccountApi.md#delete_account_item) | **DELETE** /Account/{id} | Delete a record of the Account
*AccountApi* | [**follow_account**](docs/AccountApi.md#follow_account) | **PUT** /Account/{id}/subscription | Follow the Account stream
*AccountApi* | [**get_account_item**](docs/AccountApi.md#get_account_item) | **GET** /Account/{id} | Returns a record of the Account
*AccountApi* | [**get_linked_items_for_account_item**](docs/AccountApi.md#get_linked_items_for_account_item) | **GET** /Account/{id}/{link} | Returns linked entities for the Account
*AccountApi* | [**get_list_of_account_items**](docs/AccountApi.md#get_list_of_account_items) | **GET** /Account | Returns a collection of Account records
*AccountApi* | [**link_account**](docs/AccountApi.md#link_account) | **POST** /Account/{id}/{link} | Link Account to Entities
*AccountApi* | [**mass_delete_account**](docs/AccountApi.md#mass_delete_account) | **POST** /Account/action/massDelete | Mass delete of Account data
*AccountApi* | [**mass_update_account**](docs/AccountApi.md#mass_update_account) | **PUT** /Account/action/massUpdate | Mass update of Account data
*AccountApi* | [**remove_relation_for_account**](docs/AccountApi.md#remove_relation_for_account) | **DELETE** /Account/{link}/relation | Remove relation for Account
*AccountApi* | [**unfollow_account**](docs/AccountApi.md#unfollow_account) | **DELETE** /Account/{id}/subscription | Unfollow the Account stream
*AccountApi* | [**unlink_account**](docs/AccountApi.md#unlink_account) | **DELETE** /Account/{id}/{link} | Unlink Account from Entities
*AccountApi* | [**update_account_item**](docs/AccountApi.md#update_account_item) | **PUT** /Account/{id} | Update a record of the Account
*AppApi* | [**get_authorized_user_data**](docs/AppApi.md#get_authorized_user_data) | **GET** /App/user | Generate authorization token and return authorized user data.
*AssetApi* | [**add_relation_for_asset**](docs/AssetApi.md#add_relation_for_asset) | **POST** /Asset/{link}/relation | Add relation for Asset
*AssetApi* | [**create_asset_item**](docs/AssetApi.md#create_asset_item) | **POST** /Asset | Create a record of the Asset
*AssetApi* | [**delete_asset_item**](docs/AssetApi.md#delete_asset_item) | **DELETE** /Asset/{id} | Delete a record of the Asset
*AssetApi* | [**follow_asset**](docs/AssetApi.md#follow_asset) | **PUT** /Asset/{id}/subscription | Follow the Asset stream
*AssetApi* | [**get_asset_item**](docs/AssetApi.md#get_asset_item) | **GET** /Asset/{id} | Returns a record of the Asset
*AssetApi* | [**get_linked_items_for_asset_item**](docs/AssetApi.md#get_linked_items_for_asset_item) | **GET** /Asset/{id}/{link} | Returns linked entities for the Asset
*AssetApi* | [**get_list_of_asset_items**](docs/AssetApi.md#get_list_of_asset_items) | **GET** /Asset | Returns a collection of Asset records
*AssetApi* | [**link_asset**](docs/AssetApi.md#link_asset) | **POST** /Asset/{id}/{link} | Link Asset to Entities
*AssetApi* | [**mass_delete_asset**](docs/AssetApi.md#mass_delete_asset) | **POST** /Asset/action/massDelete | Mass delete of Asset data
*AssetApi* | [**mass_update_asset**](docs/AssetApi.md#mass_update_asset) | **PUT** /Asset/action/massUpdate | Mass update of Asset data
*AssetApi* | [**remove_relation_for_asset**](docs/AssetApi.md#remove_relation_for_asset) | **DELETE** /Asset/{link}/relation | Remove relation for Asset
*AssetApi* | [**unfollow_asset**](docs/AssetApi.md#unfollow_asset) | **DELETE** /Asset/{id}/subscription | Unfollow the Asset stream
*AssetApi* | [**unlink_asset**](docs/AssetApi.md#unlink_asset) | **DELETE** /Asset/{id}/{link} | Unlink Asset from Entities
*AssetApi* | [**update_asset_item**](docs/AssetApi.md#update_asset_item) | **PUT** /Asset/{id} | Update a record of the Asset
*AssetCategoryApi* | [**add_relation_for_asset_category**](docs/AssetCategoryApi.md#add_relation_for_asset_category) | **POST** /AssetCategory/{link}/relation | Add relation for AssetCategory
*AssetCategoryApi* | [**create_asset_category_item**](docs/AssetCategoryApi.md#create_asset_category_item) | **POST** /AssetCategory | Create a record of the AssetCategory
*AssetCategoryApi* | [**delete_asset_category_item**](docs/AssetCategoryApi.md#delete_asset_category_item) | **DELETE** /AssetCategory/{id} | Delete a record of the AssetCategory
*AssetCategoryApi* | [**follow_asset_category**](docs/AssetCategoryApi.md#follow_asset_category) | **PUT** /AssetCategory/{id}/subscription | Follow the AssetCategory stream
*AssetCategoryApi* | [**get_asset_category_item**](docs/AssetCategoryApi.md#get_asset_category_item) | **GET** /AssetCategory/{id} | Returns a record of the AssetCategory
*AssetCategoryApi* | [**get_linked_items_for_asset_category_item**](docs/AssetCategoryApi.md#get_linked_items_for_asset_category_item) | **GET** /AssetCategory/{id}/{link} | Returns linked entities for the AssetCategory
*AssetCategoryApi* | [**get_list_of_asset_category_items**](docs/AssetCategoryApi.md#get_list_of_asset_category_items) | **GET** /AssetCategory | Returns a collection of AssetCategory records
*AssetCategoryApi* | [**link_asset_category**](docs/AssetCategoryApi.md#link_asset_category) | **POST** /AssetCategory/{id}/{link} | Link AssetCategory to Entities
*AssetCategoryApi* | [**mass_delete_asset_category**](docs/AssetCategoryApi.md#mass_delete_asset_category) | **POST** /AssetCategory/action/massDelete | Mass delete of AssetCategory data
*AssetCategoryApi* | [**mass_update_asset_category**](docs/AssetCategoryApi.md#mass_update_asset_category) | **PUT** /AssetCategory/action/massUpdate | Mass update of AssetCategory data
*AssetCategoryApi* | [**remove_relation_for_asset_category**](docs/AssetCategoryApi.md#remove_relation_for_asset_category) | **DELETE** /AssetCategory/{link}/relation | Remove relation for AssetCategory
*AssetCategoryApi* | [**unfollow_asset_category**](docs/AssetCategoryApi.md#unfollow_asset_category) | **DELETE** /AssetCategory/{id}/subscription | Unfollow the AssetCategory stream
*AssetCategoryApi* | [**unlink_asset_category**](docs/AssetCategoryApi.md#unlink_asset_category) | **DELETE** /AssetCategory/{id}/{link} | Unlink AssetCategory from Entities
*AssetCategoryApi* | [**update_asset_category_item**](docs/AssetCategoryApi.md#update_asset_category_item) | **PUT** /AssetCategory/{id} | Update a record of the AssetCategory
*AssetMetadataApi* | [**add_relation_for_asset_metadata**](docs/AssetMetadataApi.md#add_relation_for_asset_metadata) | **POST** /AssetMetadata/{link}/relation | Add relation for AssetMetadata
*AssetMetadataApi* | [**create_asset_metadata_item**](docs/AssetMetadataApi.md#create_asset_metadata_item) | **POST** /AssetMetadata | Create a record of the AssetMetadata
*AssetMetadataApi* | [**delete_asset_metadata_item**](docs/AssetMetadataApi.md#delete_asset_metadata_item) | **DELETE** /AssetMetadata/{id} | Delete a record of the AssetMetadata
*AssetMetadataApi* | [**follow_asset_metadata**](docs/AssetMetadataApi.md#follow_asset_metadata) | **PUT** /AssetMetadata/{id}/subscription | Follow the AssetMetadata stream
*AssetMetadataApi* | [**get_asset_metadata_item**](docs/AssetMetadataApi.md#get_asset_metadata_item) | **GET** /AssetMetadata/{id} | Returns a record of the AssetMetadata
*AssetMetadataApi* | [**get_linked_items_for_asset_metadata_item**](docs/AssetMetadataApi.md#get_linked_items_for_asset_metadata_item) | **GET** /AssetMetadata/{id}/{link} | Returns linked entities for the AssetMetadata
*AssetMetadataApi* | [**get_list_of_asset_metadata_items**](docs/AssetMetadataApi.md#get_list_of_asset_metadata_items) | **GET** /AssetMetadata | Returns a collection of AssetMetadata records
*AssetMetadataApi* | [**link_asset_metadata**](docs/AssetMetadataApi.md#link_asset_metadata) | **POST** /AssetMetadata/{id}/{link} | Link AssetMetadata to Entities
*AssetMetadataApi* | [**mass_delete_asset_metadata**](docs/AssetMetadataApi.md#mass_delete_asset_metadata) | **POST** /AssetMetadata/action/massDelete | Mass delete of AssetMetadata data
*AssetMetadataApi* | [**mass_update_asset_metadata**](docs/AssetMetadataApi.md#mass_update_asset_metadata) | **PUT** /AssetMetadata/action/massUpdate | Mass update of AssetMetadata data
*AssetMetadataApi* | [**remove_relation_for_asset_metadata**](docs/AssetMetadataApi.md#remove_relation_for_asset_metadata) | **DELETE** /AssetMetadata/{link}/relation | Remove relation for AssetMetadata
*AssetMetadataApi* | [**unfollow_asset_metadata**](docs/AssetMetadataApi.md#unfollow_asset_metadata) | **DELETE** /AssetMetadata/{id}/subscription | Unfollow the AssetMetadata stream
*AssetMetadataApi* | [**unlink_asset_metadata**](docs/AssetMetadataApi.md#unlink_asset_metadata) | **DELETE** /AssetMetadata/{id}/{link} | Unlink AssetMetadata from Entities
*AssetMetadataApi* | [**update_asset_metadata_item**](docs/AssetMetadataApi.md#update_asset_metadata_item) | **PUT** /AssetMetadata/{id} | Update a record of the AssetMetadata
*AssetTypeApi* | [**add_relation_for_asset_type**](docs/AssetTypeApi.md#add_relation_for_asset_type) | **POST** /AssetType/{link}/relation | Add relation for AssetType
*AssetTypeApi* | [**create_asset_type_item**](docs/AssetTypeApi.md#create_asset_type_item) | **POST** /AssetType | Create a record of the AssetType
*AssetTypeApi* | [**delete_asset_type_item**](docs/AssetTypeApi.md#delete_asset_type_item) | **DELETE** /AssetType/{id} | Delete a record of the AssetType
*AssetTypeApi* | [**follow_asset_type**](docs/AssetTypeApi.md#follow_asset_type) | **PUT** /AssetType/{id}/subscription | Follow the AssetType stream
*AssetTypeApi* | [**get_asset_type_item**](docs/AssetTypeApi.md#get_asset_type_item) | **GET** /AssetType/{id} | Returns a record of the AssetType
*AssetTypeApi* | [**get_linked_items_for_asset_type_item**](docs/AssetTypeApi.md#get_linked_items_for_asset_type_item) | **GET** /AssetType/{id}/{link} | Returns linked entities for the AssetType
*AssetTypeApi* | [**get_list_of_asset_type_items**](docs/AssetTypeApi.md#get_list_of_asset_type_items) | **GET** /AssetType | Returns a collection of AssetType records
*AssetTypeApi* | [**link_asset_type**](docs/AssetTypeApi.md#link_asset_type) | **POST** /AssetType/{id}/{link} | Link AssetType to Entities
*AssetTypeApi* | [**mass_delete_asset_type**](docs/AssetTypeApi.md#mass_delete_asset_type) | **POST** /AssetType/action/massDelete | Mass delete of AssetType data
*AssetTypeApi* | [**mass_update_asset_type**](docs/AssetTypeApi.md#mass_update_asset_type) | **PUT** /AssetType/action/massUpdate | Mass update of AssetType data
*AssetTypeApi* | [**remove_relation_for_asset_type**](docs/AssetTypeApi.md#remove_relation_for_asset_type) | **DELETE** /AssetType/{link}/relation | Remove relation for AssetType
*AssetTypeApi* | [**unfollow_asset_type**](docs/AssetTypeApi.md#unfollow_asset_type) | **DELETE** /AssetType/{id}/subscription | Unfollow the AssetType stream
*AssetTypeApi* | [**unlink_asset_type**](docs/AssetTypeApi.md#unlink_asset_type) | **DELETE** /AssetType/{id}/{link} | Unlink AssetType from Entities
*AssetTypeApi* | [**update_asset_type_item**](docs/AssetTypeApi.md#update_asset_type_item) | **PUT** /AssetType/{id} | Update a record of the AssetType
*AssociatedProductApi* | [**add_relation_for_associated_product**](docs/AssociatedProductApi.md#add_relation_for_associated_product) | **POST** /AssociatedProduct/{link}/relation | Add relation for AssociatedProduct
*AssociatedProductApi* | [**create_associated_product_item**](docs/AssociatedProductApi.md#create_associated_product_item) | **POST** /AssociatedProduct | Create a record of the AssociatedProduct
*AssociatedProductApi* | [**delete_associated_product_item**](docs/AssociatedProductApi.md#delete_associated_product_item) | **DELETE** /AssociatedProduct/{id} | Delete a record of the AssociatedProduct
*AssociatedProductApi* | [**follow_associated_product**](docs/AssociatedProductApi.md#follow_associated_product) | **PUT** /AssociatedProduct/{id}/subscription | Follow the AssociatedProduct stream
*AssociatedProductApi* | [**get_associated_product_item**](docs/AssociatedProductApi.md#get_associated_product_item) | **GET** /AssociatedProduct/{id} | Returns a record of the AssociatedProduct
*AssociatedProductApi* | [**get_linked_items_for_associated_product_item**](docs/AssociatedProductApi.md#get_linked_items_for_associated_product_item) | **GET** /AssociatedProduct/{id}/{link} | Returns linked entities for the AssociatedProduct
*AssociatedProductApi* | [**get_list_of_associated_product_items**](docs/AssociatedProductApi.md#get_list_of_associated_product_items) | **GET** /AssociatedProduct | Returns a collection of AssociatedProduct records
*AssociatedProductApi* | [**link_associated_product**](docs/AssociatedProductApi.md#link_associated_product) | **POST** /AssociatedProduct/{id}/{link} | Link AssociatedProduct to Entities
*AssociatedProductApi* | [**mass_delete_associated_product**](docs/AssociatedProductApi.md#mass_delete_associated_product) | **POST** /AssociatedProduct/action/massDelete | Mass delete of AssociatedProduct data
*AssociatedProductApi* | [**mass_update_associated_product**](docs/AssociatedProductApi.md#mass_update_associated_product) | **PUT** /AssociatedProduct/action/massUpdate | Mass update of AssociatedProduct data
*AssociatedProductApi* | [**remove_relation_for_associated_product**](docs/AssociatedProductApi.md#remove_relation_for_associated_product) | **DELETE** /AssociatedProduct/{link}/relation | Remove relation for AssociatedProduct
*AssociatedProductApi* | [**unfollow_associated_product**](docs/AssociatedProductApi.md#unfollow_associated_product) | **DELETE** /AssociatedProduct/{id}/subscription | Unfollow the AssociatedProduct stream
*AssociatedProductApi* | [**unlink_associated_product**](docs/AssociatedProductApi.md#unlink_associated_product) | **DELETE** /AssociatedProduct/{id}/{link} | Unlink AssociatedProduct from Entities
*AssociatedProductApi* | [**update_associated_product_item**](docs/AssociatedProductApi.md#update_associated_product_item) | **PUT** /AssociatedProduct/{id} | Update a record of the AssociatedProduct
*AssociationApi* | [**add_relation_for_association**](docs/AssociationApi.md#add_relation_for_association) | **POST** /Association/{link}/relation | Add relation for Association
*AssociationApi* | [**create_association_item**](docs/AssociationApi.md#create_association_item) | **POST** /Association | Create a record of the Association
*AssociationApi* | [**delete_association_item**](docs/AssociationApi.md#delete_association_item) | **DELETE** /Association/{id} | Delete a record of the Association
*AssociationApi* | [**follow_association**](docs/AssociationApi.md#follow_association) | **PUT** /Association/{id}/subscription | Follow the Association stream
*AssociationApi* | [**get_association_item**](docs/AssociationApi.md#get_association_item) | **GET** /Association/{id} | Returns a record of the Association
*AssociationApi* | [**get_linked_items_for_association_item**](docs/AssociationApi.md#get_linked_items_for_association_item) | **GET** /Association/{id}/{link} | Returns linked entities for the Association
*AssociationApi* | [**get_list_of_association_items**](docs/AssociationApi.md#get_list_of_association_items) | **GET** /Association | Returns a collection of Association records
*AssociationApi* | [**link_association**](docs/AssociationApi.md#link_association) | **POST** /Association/{id}/{link} | Link Association to Entities
*AssociationApi* | [**mass_delete_association**](docs/AssociationApi.md#mass_delete_association) | **POST** /Association/action/massDelete | Mass delete of Association data
*AssociationApi* | [**mass_update_association**](docs/AssociationApi.md#mass_update_association) | **PUT** /Association/action/massUpdate | Mass update of Association data
*AssociationApi* | [**remove_relation_for_association**](docs/AssociationApi.md#remove_relation_for_association) | **DELETE** /Association/{link}/relation | Remove relation for Association
*AssociationApi* | [**unfollow_association**](docs/AssociationApi.md#unfollow_association) | **DELETE** /Association/{id}/subscription | Unfollow the Association stream
*AssociationApi* | [**unlink_association**](docs/AssociationApi.md#unlink_association) | **DELETE** /Association/{id}/{link} | Unlink Association from Entities
*AssociationApi* | [**update_association_item**](docs/AssociationApi.md#update_association_item) | **PUT** /Association/{id} | Update a record of the Association
*AttachmentApi* | [**add_relation_for_attachment**](docs/AttachmentApi.md#add_relation_for_attachment) | **POST** /Attachment/{link}/relation | Add relation for Attachment
*AttachmentApi* | [**create_attachment_item**](docs/AttachmentApi.md#create_attachment_item) | **POST** /Attachment | Create a record of the Attachment
*AttachmentApi* | [**delete_attachment_item**](docs/AttachmentApi.md#delete_attachment_item) | **DELETE** /Attachment/{id} | Delete a record of the Attachment
*AttachmentApi* | [**follow_attachment**](docs/AttachmentApi.md#follow_attachment) | **PUT** /Attachment/{id}/subscription | Follow the Attachment stream
*AttachmentApi* | [**get_attachment_item**](docs/AttachmentApi.md#get_attachment_item) | **GET** /Attachment/{id} | Returns a record of the Attachment
*AttachmentApi* | [**get_linked_items_for_attachment_item**](docs/AttachmentApi.md#get_linked_items_for_attachment_item) | **GET** /Attachment/{id}/{link} | Returns linked entities for the Attachment
*AttachmentApi* | [**get_list_of_attachment_items**](docs/AttachmentApi.md#get_list_of_attachment_items) | **GET** /Attachment | Returns a collection of Attachment records
*AttachmentApi* | [**link_attachment**](docs/AttachmentApi.md#link_attachment) | **POST** /Attachment/{id}/{link} | Link Attachment to Entities
*AttachmentApi* | [**mass_delete_attachment**](docs/AttachmentApi.md#mass_delete_attachment) | **POST** /Attachment/action/massDelete | Mass delete of Attachment data
*AttachmentApi* | [**mass_update_attachment**](docs/AttachmentApi.md#mass_update_attachment) | **PUT** /Attachment/action/massUpdate | Mass update of Attachment data
*AttachmentApi* | [**remove_relation_for_attachment**](docs/AttachmentApi.md#remove_relation_for_attachment) | **DELETE** /Attachment/{link}/relation | Remove relation for Attachment
*AttachmentApi* | [**unfollow_attachment**](docs/AttachmentApi.md#unfollow_attachment) | **DELETE** /Attachment/{id}/subscription | Unfollow the Attachment stream
*AttachmentApi* | [**unlink_attachment**](docs/AttachmentApi.md#unlink_attachment) | **DELETE** /Attachment/{id}/{link} | Unlink Attachment from Entities
*AttachmentApi* | [**update_attachment_item**](docs/AttachmentApi.md#update_attachment_item) | **PUT** /Attachment/{id} | Update a record of the Attachment
*AttributeApi* | [**add_relation_for_attribute**](docs/AttributeApi.md#add_relation_for_attribute) | **POST** /Attribute/{link}/relation | Add relation for Attribute
*AttributeApi* | [**create_attribute_item**](docs/AttributeApi.md#create_attribute_item) | **POST** /Attribute | Create a record of the Attribute
*AttributeApi* | [**delete_attribute_item**](docs/AttributeApi.md#delete_attribute_item) | **DELETE** /Attribute/{id} | Delete a record of the Attribute
*AttributeApi* | [**follow_attribute**](docs/AttributeApi.md#follow_attribute) | **PUT** /Attribute/{id}/subscription | Follow the Attribute stream
*AttributeApi* | [**get_attribute_item**](docs/AttributeApi.md#get_attribute_item) | **GET** /Attribute/{id} | Returns a record of the Attribute
*AttributeApi* | [**get_linked_items_for_attribute_item**](docs/AttributeApi.md#get_linked_items_for_attribute_item) | **GET** /Attribute/{id}/{link} | Returns linked entities for the Attribute
*AttributeApi* | [**get_list_of_attribute_items**](docs/AttributeApi.md#get_list_of_attribute_items) | **GET** /Attribute | Returns a collection of Attribute records
*AttributeApi* | [**link_attribute**](docs/AttributeApi.md#link_attribute) | **POST** /Attribute/{id}/{link} | Link Attribute to Entities
*AttributeApi* | [**mass_delete_attribute**](docs/AttributeApi.md#mass_delete_attribute) | **POST** /Attribute/action/massDelete | Mass delete of Attribute data
*AttributeApi* | [**mass_update_attribute**](docs/AttributeApi.md#mass_update_attribute) | **PUT** /Attribute/action/massUpdate | Mass update of Attribute data
*AttributeApi* | [**remove_relation_for_attribute**](docs/AttributeApi.md#remove_relation_for_attribute) | **DELETE** /Attribute/{link}/relation | Remove relation for Attribute
*AttributeApi* | [**unfollow_attribute**](docs/AttributeApi.md#unfollow_attribute) | **DELETE** /Attribute/{id}/subscription | Unfollow the Attribute stream
*AttributeApi* | [**unlink_attribute**](docs/AttributeApi.md#unlink_attribute) | **DELETE** /Attribute/{id}/{link} | Unlink Attribute from Entities
*AttributeApi* | [**update_attribute_item**](docs/AttributeApi.md#update_attribute_item) | **PUT** /Attribute/{id} | Update a record of the Attribute
*AttributeGroupApi* | [**add_relation_for_attribute_group**](docs/AttributeGroupApi.md#add_relation_for_attribute_group) | **POST** /AttributeGroup/{link}/relation | Add relation for AttributeGroup
*AttributeGroupApi* | [**create_attribute_group_item**](docs/AttributeGroupApi.md#create_attribute_group_item) | **POST** /AttributeGroup | Create a record of the AttributeGroup
*AttributeGroupApi* | [**delete_attribute_group_item**](docs/AttributeGroupApi.md#delete_attribute_group_item) | **DELETE** /AttributeGroup/{id} | Delete a record of the AttributeGroup
*AttributeGroupApi* | [**follow_attribute_group**](docs/AttributeGroupApi.md#follow_attribute_group) | **PUT** /AttributeGroup/{id}/subscription | Follow the AttributeGroup stream
*AttributeGroupApi* | [**get_attribute_group_item**](docs/AttributeGroupApi.md#get_attribute_group_item) | **GET** /AttributeGroup/{id} | Returns a record of the AttributeGroup
*AttributeGroupApi* | [**get_linked_items_for_attribute_group_item**](docs/AttributeGroupApi.md#get_linked_items_for_attribute_group_item) | **GET** /AttributeGroup/{id}/{link} | Returns linked entities for the AttributeGroup
*AttributeGroupApi* | [**get_list_of_attribute_group_items**](docs/AttributeGroupApi.md#get_list_of_attribute_group_items) | **GET** /AttributeGroup | Returns a collection of AttributeGroup records
*AttributeGroupApi* | [**link_attribute_group**](docs/AttributeGroupApi.md#link_attribute_group) | **POST** /AttributeGroup/{id}/{link} | Link AttributeGroup to Entities
*AttributeGroupApi* | [**mass_delete_attribute_group**](docs/AttributeGroupApi.md#mass_delete_attribute_group) | **POST** /AttributeGroup/action/massDelete | Mass delete of AttributeGroup data
*AttributeGroupApi* | [**mass_update_attribute_group**](docs/AttributeGroupApi.md#mass_update_attribute_group) | **PUT** /AttributeGroup/action/massUpdate | Mass update of AttributeGroup data
*AttributeGroupApi* | [**remove_relation_for_attribute_group**](docs/AttributeGroupApi.md#remove_relation_for_attribute_group) | **DELETE** /AttributeGroup/{link}/relation | Remove relation for AttributeGroup
*AttributeGroupApi* | [**unfollow_attribute_group**](docs/AttributeGroupApi.md#unfollow_attribute_group) | **DELETE** /AttributeGroup/{id}/subscription | Unfollow the AttributeGroup stream
*AttributeGroupApi* | [**unlink_attribute_group**](docs/AttributeGroupApi.md#unlink_attribute_group) | **DELETE** /AttributeGroup/{id}/{link} | Unlink AttributeGroup from Entities
*AttributeGroupApi* | [**update_attribute_group_item**](docs/AttributeGroupApi.md#update_attribute_group_item) | **PUT** /AttributeGroup/{id} | Update a record of the AttributeGroup
*AttributeTabApi* | [**add_relation_for_attribute_tab**](docs/AttributeTabApi.md#add_relation_for_attribute_tab) | **POST** /AttributeTab/{link}/relation | Add relation for AttributeTab
*AttributeTabApi* | [**create_attribute_tab_item**](docs/AttributeTabApi.md#create_attribute_tab_item) | **POST** /AttributeTab | Create a record of the AttributeTab
*AttributeTabApi* | [**delete_attribute_tab_item**](docs/AttributeTabApi.md#delete_attribute_tab_item) | **DELETE** /AttributeTab/{id} | Delete a record of the AttributeTab
*AttributeTabApi* | [**follow_attribute_tab**](docs/AttributeTabApi.md#follow_attribute_tab) | **PUT** /AttributeTab/{id}/subscription | Follow the AttributeTab stream
*AttributeTabApi* | [**get_attribute_tab_item**](docs/AttributeTabApi.md#get_attribute_tab_item) | **GET** /AttributeTab/{id} | Returns a record of the AttributeTab
*AttributeTabApi* | [**get_linked_items_for_attribute_tab_item**](docs/AttributeTabApi.md#get_linked_items_for_attribute_tab_item) | **GET** /AttributeTab/{id}/{link} | Returns linked entities for the AttributeTab
*AttributeTabApi* | [**get_list_of_attribute_tab_items**](docs/AttributeTabApi.md#get_list_of_attribute_tab_items) | **GET** /AttributeTab | Returns a collection of AttributeTab records
*AttributeTabApi* | [**link_attribute_tab**](docs/AttributeTabApi.md#link_attribute_tab) | **POST** /AttributeTab/{id}/{link} | Link AttributeTab to Entities
*AttributeTabApi* | [**mass_delete_attribute_tab**](docs/AttributeTabApi.md#mass_delete_attribute_tab) | **POST** /AttributeTab/action/massDelete | Mass delete of AttributeTab data
*AttributeTabApi* | [**mass_update_attribute_tab**](docs/AttributeTabApi.md#mass_update_attribute_tab) | **PUT** /AttributeTab/action/massUpdate | Mass update of AttributeTab data
*AttributeTabApi* | [**remove_relation_for_attribute_tab**](docs/AttributeTabApi.md#remove_relation_for_attribute_tab) | **DELETE** /AttributeTab/{link}/relation | Remove relation for AttributeTab
*AttributeTabApi* | [**unfollow_attribute_tab**](docs/AttributeTabApi.md#unfollow_attribute_tab) | **DELETE** /AttributeTab/{id}/subscription | Unfollow the AttributeTab stream
*AttributeTabApi* | [**unlink_attribute_tab**](docs/AttributeTabApi.md#unlink_attribute_tab) | **DELETE** /AttributeTab/{id}/{link} | Unlink AttributeTab from Entities
*AttributeTabApi* | [**update_attribute_tab_item**](docs/AttributeTabApi.md#update_attribute_tab_item) | **PUT** /AttributeTab/{id} | Update a record of the AttributeTab
*AuthLogRecordApi* | [**add_relation_for_auth_log_record**](docs/AuthLogRecordApi.md#add_relation_for_auth_log_record) | **POST** /AuthLogRecord/{link}/relation | Add relation for AuthLogRecord
*AuthLogRecordApi* | [**create_auth_log_record_item**](docs/AuthLogRecordApi.md#create_auth_log_record_item) | **POST** /AuthLogRecord | Create a record of the AuthLogRecord
*AuthLogRecordApi* | [**delete_auth_log_record_item**](docs/AuthLogRecordApi.md#delete_auth_log_record_item) | **DELETE** /AuthLogRecord/{id} | Delete a record of the AuthLogRecord
*AuthLogRecordApi* | [**follow_auth_log_record**](docs/AuthLogRecordApi.md#follow_auth_log_record) | **PUT** /AuthLogRecord/{id}/subscription | Follow the AuthLogRecord stream
*AuthLogRecordApi* | [**get_auth_log_record_item**](docs/AuthLogRecordApi.md#get_auth_log_record_item) | **GET** /AuthLogRecord/{id} | Returns a record of the AuthLogRecord
*AuthLogRecordApi* | [**get_linked_items_for_auth_log_record_item**](docs/AuthLogRecordApi.md#get_linked_items_for_auth_log_record_item) | **GET** /AuthLogRecord/{id}/{link} | Returns linked entities for the AuthLogRecord
*AuthLogRecordApi* | [**get_list_of_auth_log_record_items**](docs/AuthLogRecordApi.md#get_list_of_auth_log_record_items) | **GET** /AuthLogRecord | Returns a collection of AuthLogRecord records
*AuthLogRecordApi* | [**link_auth_log_record**](docs/AuthLogRecordApi.md#link_auth_log_record) | **POST** /AuthLogRecord/{id}/{link} | Link AuthLogRecord to Entities
*AuthLogRecordApi* | [**mass_delete_auth_log_record**](docs/AuthLogRecordApi.md#mass_delete_auth_log_record) | **POST** /AuthLogRecord/action/massDelete | Mass delete of AuthLogRecord data
*AuthLogRecordApi* | [**mass_update_auth_log_record**](docs/AuthLogRecordApi.md#mass_update_auth_log_record) | **PUT** /AuthLogRecord/action/massUpdate | Mass update of AuthLogRecord data
*AuthLogRecordApi* | [**remove_relation_for_auth_log_record**](docs/AuthLogRecordApi.md#remove_relation_for_auth_log_record) | **DELETE** /AuthLogRecord/{link}/relation | Remove relation for AuthLogRecord
*AuthLogRecordApi* | [**unfollow_auth_log_record**](docs/AuthLogRecordApi.md#unfollow_auth_log_record) | **DELETE** /AuthLogRecord/{id}/subscription | Unfollow the AuthLogRecord stream
*AuthLogRecordApi* | [**unlink_auth_log_record**](docs/AuthLogRecordApi.md#unlink_auth_log_record) | **DELETE** /AuthLogRecord/{id}/{link} | Unlink AuthLogRecord from Entities
*AuthLogRecordApi* | [**update_auth_log_record_item**](docs/AuthLogRecordApi.md#update_auth_log_record_item) | **PUT** /AuthLogRecord/{id} | Update a record of the AuthLogRecord
*AuthTokenApi* | [**add_relation_for_auth_token**](docs/AuthTokenApi.md#add_relation_for_auth_token) | **POST** /AuthToken/{link}/relation | Add relation for AuthToken
*AuthTokenApi* | [**create_auth_token_item**](docs/AuthTokenApi.md#create_auth_token_item) | **POST** /AuthToken | Create a record of the AuthToken
*AuthTokenApi* | [**delete_auth_token_item**](docs/AuthTokenApi.md#delete_auth_token_item) | **DELETE** /AuthToken/{id} | Delete a record of the AuthToken
*AuthTokenApi* | [**follow_auth_token**](docs/AuthTokenApi.md#follow_auth_token) | **PUT** /AuthToken/{id}/subscription | Follow the AuthToken stream
*AuthTokenApi* | [**get_auth_token_item**](docs/AuthTokenApi.md#get_auth_token_item) | **GET** /AuthToken/{id} | Returns a record of the AuthToken
*AuthTokenApi* | [**get_linked_items_for_auth_token_item**](docs/AuthTokenApi.md#get_linked_items_for_auth_token_item) | **GET** /AuthToken/{id}/{link} | Returns linked entities for the AuthToken
*AuthTokenApi* | [**get_list_of_auth_token_items**](docs/AuthTokenApi.md#get_list_of_auth_token_items) | **GET** /AuthToken | Returns a collection of AuthToken records
*AuthTokenApi* | [**link_auth_token**](docs/AuthTokenApi.md#link_auth_token) | **POST** /AuthToken/{id}/{link} | Link AuthToken to Entities
*AuthTokenApi* | [**mass_delete_auth_token**](docs/AuthTokenApi.md#mass_delete_auth_token) | **POST** /AuthToken/action/massDelete | Mass delete of AuthToken data
*AuthTokenApi* | [**mass_update_auth_token**](docs/AuthTokenApi.md#mass_update_auth_token) | **PUT** /AuthToken/action/massUpdate | Mass update of AuthToken data
*AuthTokenApi* | [**remove_relation_for_auth_token**](docs/AuthTokenApi.md#remove_relation_for_auth_token) | **DELETE** /AuthToken/{link}/relation | Remove relation for AuthToken
*AuthTokenApi* | [**unfollow_auth_token**](docs/AuthTokenApi.md#unfollow_auth_token) | **DELETE** /AuthToken/{id}/subscription | Unfollow the AuthToken stream
*AuthTokenApi* | [**unlink_auth_token**](docs/AuthTokenApi.md#unlink_auth_token) | **DELETE** /AuthToken/{id}/{link} | Unlink AuthToken from Entities
*AuthTokenApi* | [**update_auth_token_item**](docs/AuthTokenApi.md#update_auth_token_item) | **PUT** /AuthToken/{id} | Update a record of the AuthToken
*BrandApi* | [**add_relation_for_brand**](docs/BrandApi.md#add_relation_for_brand) | **POST** /Brand/{link}/relation | Add relation for Brand
*BrandApi* | [**create_brand_item**](docs/BrandApi.md#create_brand_item) | **POST** /Brand | Create a record of the Brand
*BrandApi* | [**delete_brand_item**](docs/BrandApi.md#delete_brand_item) | **DELETE** /Brand/{id} | Delete a record of the Brand
*BrandApi* | [**follow_brand**](docs/BrandApi.md#follow_brand) | **PUT** /Brand/{id}/subscription | Follow the Brand stream
*BrandApi* | [**get_brand_item**](docs/BrandApi.md#get_brand_item) | **GET** /Brand/{id} | Returns a record of the Brand
*BrandApi* | [**get_linked_items_for_brand_item**](docs/BrandApi.md#get_linked_items_for_brand_item) | **GET** /Brand/{id}/{link} | Returns linked entities for the Brand
*BrandApi* | [**get_list_of_brand_items**](docs/BrandApi.md#get_list_of_brand_items) | **GET** /Brand | Returns a collection of Brand records
*BrandApi* | [**link_brand**](docs/BrandApi.md#link_brand) | **POST** /Brand/{id}/{link} | Link Brand to Entities
*BrandApi* | [**mass_delete_brand**](docs/BrandApi.md#mass_delete_brand) | **POST** /Brand/action/massDelete | Mass delete of Brand data
*BrandApi* | [**mass_update_brand**](docs/BrandApi.md#mass_update_brand) | **PUT** /Brand/action/massUpdate | Mass update of Brand data
*BrandApi* | [**remove_relation_for_brand**](docs/BrandApi.md#remove_relation_for_brand) | **DELETE** /Brand/{link}/relation | Remove relation for Brand
*BrandApi* | [**unfollow_brand**](docs/BrandApi.md#unfollow_brand) | **DELETE** /Brand/{id}/subscription | Unfollow the Brand stream
*BrandApi* | [**unlink_brand**](docs/BrandApi.md#unlink_brand) | **DELETE** /Brand/{id}/{link} | Unlink Brand from Entities
*BrandApi* | [**update_brand_item**](docs/BrandApi.md#update_brand_item) | **PUT** /Brand/{id} | Update a record of the Brand
*CatalogApi* | [**add_relation_for_catalog**](docs/CatalogApi.md#add_relation_for_catalog) | **POST** /Catalog/{link}/relation | Add relation for Catalog
*CatalogApi* | [**create_catalog_item**](docs/CatalogApi.md#create_catalog_item) | **POST** /Catalog | Create a record of the Catalog
*CatalogApi* | [**delete_catalog_item**](docs/CatalogApi.md#delete_catalog_item) | **DELETE** /Catalog/{id} | Delete a record of the Catalog
*CatalogApi* | [**follow_catalog**](docs/CatalogApi.md#follow_catalog) | **PUT** /Catalog/{id}/subscription | Follow the Catalog stream
*CatalogApi* | [**get_catalog_item**](docs/CatalogApi.md#get_catalog_item) | **GET** /Catalog/{id} | Returns a record of the Catalog
*CatalogApi* | [**get_linked_items_for_catalog_item**](docs/CatalogApi.md#get_linked_items_for_catalog_item) | **GET** /Catalog/{id}/{link} | Returns linked entities for the Catalog
*CatalogApi* | [**get_list_of_catalog_items**](docs/CatalogApi.md#get_list_of_catalog_items) | **GET** /Catalog | Returns a collection of Catalog records
*CatalogApi* | [**link_catalog**](docs/CatalogApi.md#link_catalog) | **POST** /Catalog/{id}/{link} | Link Catalog to Entities
*CatalogApi* | [**mass_delete_catalog**](docs/CatalogApi.md#mass_delete_catalog) | **POST** /Catalog/action/massDelete | Mass delete of Catalog data
*CatalogApi* | [**mass_update_catalog**](docs/CatalogApi.md#mass_update_catalog) | **PUT** /Catalog/action/massUpdate | Mass update of Catalog data
*CatalogApi* | [**remove_relation_for_catalog**](docs/CatalogApi.md#remove_relation_for_catalog) | **DELETE** /Catalog/{link}/relation | Remove relation for Catalog
*CatalogApi* | [**unfollow_catalog**](docs/CatalogApi.md#unfollow_catalog) | **DELETE** /Catalog/{id}/subscription | Unfollow the Catalog stream
*CatalogApi* | [**unlink_catalog**](docs/CatalogApi.md#unlink_catalog) | **DELETE** /Catalog/{id}/{link} | Unlink Catalog from Entities
*CatalogApi* | [**update_catalog_item**](docs/CatalogApi.md#update_catalog_item) | **PUT** /Catalog/{id} | Update a record of the Catalog
*CategoryApi* | [**add_relation_for_category**](docs/CategoryApi.md#add_relation_for_category) | **POST** /Category/{link}/relation | Add relation for Category
*CategoryApi* | [**create_category_item**](docs/CategoryApi.md#create_category_item) | **POST** /Category | Create a record of the Category
*CategoryApi* | [**delete_category_item**](docs/CategoryApi.md#delete_category_item) | **DELETE** /Category/{id} | Delete a record of the Category
*CategoryApi* | [**follow_category**](docs/CategoryApi.md#follow_category) | **PUT** /Category/{id}/subscription | Follow the Category stream
*CategoryApi* | [**get_category_item**](docs/CategoryApi.md#get_category_item) | **GET** /Category/{id} | Returns a record of the Category
*CategoryApi* | [**get_linked_items_for_category_item**](docs/CategoryApi.md#get_linked_items_for_category_item) | **GET** /Category/{id}/{link} | Returns linked entities for the Category
*CategoryApi* | [**get_list_of_category_items**](docs/CategoryApi.md#get_list_of_category_items) | **GET** /Category | Returns a collection of Category records
*CategoryApi* | [**link_category**](docs/CategoryApi.md#link_category) | **POST** /Category/{id}/{link} | Link Category to Entities
*CategoryApi* | [**mass_delete_category**](docs/CategoryApi.md#mass_delete_category) | **POST** /Category/action/massDelete | Mass delete of Category data
*CategoryApi* | [**mass_update_category**](docs/CategoryApi.md#mass_update_category) | **PUT** /Category/action/massUpdate | Mass update of Category data
*CategoryApi* | [**remove_relation_for_category**](docs/CategoryApi.md#remove_relation_for_category) | **DELETE** /Category/{link}/relation | Remove relation for Category
*CategoryApi* | [**unfollow_category**](docs/CategoryApi.md#unfollow_category) | **DELETE** /Category/{id}/subscription | Unfollow the Category stream
*CategoryApi* | [**unlink_category**](docs/CategoryApi.md#unlink_category) | **DELETE** /Category/{id}/{link} | Unlink Category from Entities
*CategoryApi* | [**update_category_item**](docs/CategoryApi.md#update_category_item) | **PUT** /Category/{id} | Update a record of the Category
*CategoryAssetApi* | [**add_relation_for_category_asset**](docs/CategoryAssetApi.md#add_relation_for_category_asset) | **POST** /CategoryAsset/{link}/relation | Add relation for CategoryAsset
*CategoryAssetApi* | [**create_category_asset_item**](docs/CategoryAssetApi.md#create_category_asset_item) | **POST** /CategoryAsset | Create a record of the CategoryAsset
*CategoryAssetApi* | [**delete_category_asset_item**](docs/CategoryAssetApi.md#delete_category_asset_item) | **DELETE** /CategoryAsset/{id} | Delete a record of the CategoryAsset
*CategoryAssetApi* | [**follow_category_asset**](docs/CategoryAssetApi.md#follow_category_asset) | **PUT** /CategoryAsset/{id}/subscription | Follow the CategoryAsset stream
*CategoryAssetApi* | [**get_category_asset_item**](docs/CategoryAssetApi.md#get_category_asset_item) | **GET** /CategoryAsset/{id} | Returns a record of the CategoryAsset
*CategoryAssetApi* | [**get_linked_items_for_category_asset_item**](docs/CategoryAssetApi.md#get_linked_items_for_category_asset_item) | **GET** /CategoryAsset/{id}/{link} | Returns linked entities for the CategoryAsset
*CategoryAssetApi* | [**get_list_of_category_asset_items**](docs/CategoryAssetApi.md#get_list_of_category_asset_items) | **GET** /CategoryAsset | Returns a collection of CategoryAsset records
*CategoryAssetApi* | [**link_category_asset**](docs/CategoryAssetApi.md#link_category_asset) | **POST** /CategoryAsset/{id}/{link} | Link CategoryAsset to Entities
*CategoryAssetApi* | [**mass_delete_category_asset**](docs/CategoryAssetApi.md#mass_delete_category_asset) | **POST** /CategoryAsset/action/massDelete | Mass delete of CategoryAsset data
*CategoryAssetApi* | [**mass_update_category_asset**](docs/CategoryAssetApi.md#mass_update_category_asset) | **PUT** /CategoryAsset/action/massUpdate | Mass update of CategoryAsset data
*CategoryAssetApi* | [**remove_relation_for_category_asset**](docs/CategoryAssetApi.md#remove_relation_for_category_asset) | **DELETE** /CategoryAsset/{link}/relation | Remove relation for CategoryAsset
*CategoryAssetApi* | [**unfollow_category_asset**](docs/CategoryAssetApi.md#unfollow_category_asset) | **DELETE** /CategoryAsset/{id}/subscription | Unfollow the CategoryAsset stream
*CategoryAssetApi* | [**unlink_category_asset**](docs/CategoryAssetApi.md#unlink_category_asset) | **DELETE** /CategoryAsset/{id}/{link} | Unlink CategoryAsset from Entities
*CategoryAssetApi* | [**update_category_asset_item**](docs/CategoryAssetApi.md#update_category_asset_item) | **PUT** /CategoryAsset/{id} | Update a record of the CategoryAsset
*ChannelApi* | [**add_relation_for_channel**](docs/ChannelApi.md#add_relation_for_channel) | **POST** /Channel/{link}/relation | Add relation for Channel
*ChannelApi* | [**create_channel_item**](docs/ChannelApi.md#create_channel_item) | **POST** /Channel | Create a record of the Channel
*ChannelApi* | [**delete_channel_item**](docs/ChannelApi.md#delete_channel_item) | **DELETE** /Channel/{id} | Delete a record of the Channel
*ChannelApi* | [**follow_channel**](docs/ChannelApi.md#follow_channel) | **PUT** /Channel/{id}/subscription | Follow the Channel stream
*ChannelApi* | [**get_channel_item**](docs/ChannelApi.md#get_channel_item) | **GET** /Channel/{id} | Returns a record of the Channel
*ChannelApi* | [**get_linked_items_for_channel_item**](docs/ChannelApi.md#get_linked_items_for_channel_item) | **GET** /Channel/{id}/{link} | Returns linked entities for the Channel
*ChannelApi* | [**get_list_of_channel_items**](docs/ChannelApi.md#get_list_of_channel_items) | **GET** /Channel | Returns a collection of Channel records
*ChannelApi* | [**link_channel**](docs/ChannelApi.md#link_channel) | **POST** /Channel/{id}/{link} | Link Channel to Entities
*ChannelApi* | [**mass_delete_channel**](docs/ChannelApi.md#mass_delete_channel) | **POST** /Channel/action/massDelete | Mass delete of Channel data
*ChannelApi* | [**mass_update_channel**](docs/ChannelApi.md#mass_update_channel) | **PUT** /Channel/action/massUpdate | Mass update of Channel data
*ChannelApi* | [**remove_relation_for_channel**](docs/ChannelApi.md#remove_relation_for_channel) | **DELETE** /Channel/{link}/relation | Remove relation for Channel
*ChannelApi* | [**unfollow_channel**](docs/ChannelApi.md#unfollow_channel) | **DELETE** /Channel/{id}/subscription | Unfollow the Channel stream
*ChannelApi* | [**unlink_channel**](docs/ChannelApi.md#unlink_channel) | **DELETE** /Channel/{id}/{link} | Unlink Channel from Entities
*ChannelApi* | [**update_channel_item**](docs/ChannelApi.md#update_channel_item) | **PUT** /Channel/{id} | Update a record of the Channel
*ClassificationApi* | [**add_relation_for_classification**](docs/ClassificationApi.md#add_relation_for_classification) | **POST** /Classification/{link}/relation | Add relation for Classification
*ClassificationApi* | [**create_classification_item**](docs/ClassificationApi.md#create_classification_item) | **POST** /Classification | Create a record of the Classification
*ClassificationApi* | [**delete_classification_item**](docs/ClassificationApi.md#delete_classification_item) | **DELETE** /Classification/{id} | Delete a record of the Classification
*ClassificationApi* | [**follow_classification**](docs/ClassificationApi.md#follow_classification) | **PUT** /Classification/{id}/subscription | Follow the Classification stream
*ClassificationApi* | [**get_classification_item**](docs/ClassificationApi.md#get_classification_item) | **GET** /Classification/{id} | Returns a record of the Classification
*ClassificationApi* | [**get_linked_items_for_classification_item**](docs/ClassificationApi.md#get_linked_items_for_classification_item) | **GET** /Classification/{id}/{link} | Returns linked entities for the Classification
*ClassificationApi* | [**get_list_of_classification_items**](docs/ClassificationApi.md#get_list_of_classification_items) | **GET** /Classification | Returns a collection of Classification records
*ClassificationApi* | [**link_classification**](docs/ClassificationApi.md#link_classification) | **POST** /Classification/{id}/{link} | Link Classification to Entities
*ClassificationApi* | [**mass_delete_classification**](docs/ClassificationApi.md#mass_delete_classification) | **POST** /Classification/action/massDelete | Mass delete of Classification data
*ClassificationApi* | [**mass_update_classification**](docs/ClassificationApi.md#mass_update_classification) | **PUT** /Classification/action/massUpdate | Mass update of Classification data
*ClassificationApi* | [**remove_relation_for_classification**](docs/ClassificationApi.md#remove_relation_for_classification) | **DELETE** /Classification/{link}/relation | Remove relation for Classification
*ClassificationApi* | [**unfollow_classification**](docs/ClassificationApi.md#unfollow_classification) | **DELETE** /Classification/{id}/subscription | Unfollow the Classification stream
*ClassificationApi* | [**unlink_classification**](docs/ClassificationApi.md#unlink_classification) | **DELETE** /Classification/{id}/{link} | Unlink Classification from Entities
*ClassificationApi* | [**update_classification_item**](docs/ClassificationApi.md#update_classification_item) | **PUT** /Classification/{id} | Update a record of the Classification
*ClassificationAttributeApi* | [**add_relation_for_classification_attribute**](docs/ClassificationAttributeApi.md#add_relation_for_classification_attribute) | **POST** /ClassificationAttribute/{link}/relation | Add relation for ClassificationAttribute
*ClassificationAttributeApi* | [**create_classification_attribute_item**](docs/ClassificationAttributeApi.md#create_classification_attribute_item) | **POST** /ClassificationAttribute | Create a record of the ClassificationAttribute
*ClassificationAttributeApi* | [**delete_classification_attribute_item**](docs/ClassificationAttributeApi.md#delete_classification_attribute_item) | **DELETE** /ClassificationAttribute/{id} | Delete a record of the ClassificationAttribute
*ClassificationAttributeApi* | [**follow_classification_attribute**](docs/ClassificationAttributeApi.md#follow_classification_attribute) | **PUT** /ClassificationAttribute/{id}/subscription | Follow the ClassificationAttribute stream
*ClassificationAttributeApi* | [**get_classification_attribute_item**](docs/ClassificationAttributeApi.md#get_classification_attribute_item) | **GET** /ClassificationAttribute/{id} | Returns a record of the ClassificationAttribute
*ClassificationAttributeApi* | [**get_linked_items_for_classification_attribute_item**](docs/ClassificationAttributeApi.md#get_linked_items_for_classification_attribute_item) | **GET** /ClassificationAttribute/{id}/{link} | Returns linked entities for the ClassificationAttribute
*ClassificationAttributeApi* | [**get_list_of_classification_attribute_items**](docs/ClassificationAttributeApi.md#get_list_of_classification_attribute_items) | **GET** /ClassificationAttribute | Returns a collection of ClassificationAttribute records
*ClassificationAttributeApi* | [**link_classification_attribute**](docs/ClassificationAttributeApi.md#link_classification_attribute) | **POST** /ClassificationAttribute/{id}/{link} | Link ClassificationAttribute to Entities
*ClassificationAttributeApi* | [**mass_delete_classification_attribute**](docs/ClassificationAttributeApi.md#mass_delete_classification_attribute) | **POST** /ClassificationAttribute/action/massDelete | Mass delete of ClassificationAttribute data
*ClassificationAttributeApi* | [**mass_update_classification_attribute**](docs/ClassificationAttributeApi.md#mass_update_classification_attribute) | **PUT** /ClassificationAttribute/action/massUpdate | Mass update of ClassificationAttribute data
*ClassificationAttributeApi* | [**remove_relation_for_classification_attribute**](docs/ClassificationAttributeApi.md#remove_relation_for_classification_attribute) | **DELETE** /ClassificationAttribute/{link}/relation | Remove relation for ClassificationAttribute
*ClassificationAttributeApi* | [**unfollow_classification_attribute**](docs/ClassificationAttributeApi.md#unfollow_classification_attribute) | **DELETE** /ClassificationAttribute/{id}/subscription | Unfollow the ClassificationAttribute stream
*ClassificationAttributeApi* | [**unlink_classification_attribute**](docs/ClassificationAttributeApi.md#unlink_classification_attribute) | **DELETE** /ClassificationAttribute/{id}/{link} | Unlink ClassificationAttribute from Entities
*ClassificationAttributeApi* | [**update_classification_attribute_item**](docs/ClassificationAttributeApi.md#update_classification_attribute_item) | **PUT** /ClassificationAttribute/{id} | Update a record of the ClassificationAttribute
*ComposerApi* | [**cancel_module**](docs/ComposerApi.md#cancel_module) | **POST** /Composer/cancel | Cancel module changes
*ComposerApi* | [**cancel_update_composer**](docs/ComposerApi.md#cancel_update_composer) | **DELETE** /Composer/cancelUpdate | Cancel changes
*ComposerApi* | [**delete_module**](docs/ComposerApi.md#delete_module) | **DELETE** /Composer/deleteModule | Delete module
*ComposerApi* | [**get_installed_modules**](docs/ComposerApi.md#get_installed_modules) | **GET** /Composer/list | Get installed modules
*ComposerApi* | [**get_modules_logs**](docs/ComposerApi.md#get_modules_logs) | **GET** /Composer/logs | Get updates logs
*ComposerApi* | [**install_module**](docs/ComposerApi.md#install_module) | **POST** /Composer/installModule | Install module
*ComposerApi* | [**run_update_composer**](docs/ComposerApi.md#run_update_composer) | **POST** /Composer/runUpdate | Run update
*ConnectionApi* | [**add_relation_for_connection**](docs/ConnectionApi.md#add_relation_for_connection) | **POST** /Connection/{link}/relation | Add relation for Connection
*ConnectionApi* | [**create_connection_item**](docs/ConnectionApi.md#create_connection_item) | **POST** /Connection | Create a record of the Connection
*ConnectionApi* | [**delete_connection_item**](docs/ConnectionApi.md#delete_connection_item) | **DELETE** /Connection/{id} | Delete a record of the Connection
*ConnectionApi* | [**follow_connection**](docs/ConnectionApi.md#follow_connection) | **PUT** /Connection/{id}/subscription | Follow the Connection stream
*ConnectionApi* | [**get_connection_item**](docs/ConnectionApi.md#get_connection_item) | **GET** /Connection/{id} | Returns a record of the Connection
*ConnectionApi* | [**get_linked_items_for_connection_item**](docs/ConnectionApi.md#get_linked_items_for_connection_item) | **GET** /Connection/{id}/{link} | Returns linked entities for the Connection
*ConnectionApi* | [**get_list_of_connection_items**](docs/ConnectionApi.md#get_list_of_connection_items) | **GET** /Connection | Returns a collection of Connection records
*ConnectionApi* | [**link_connection**](docs/ConnectionApi.md#link_connection) | **POST** /Connection/{id}/{link} | Link Connection to Entities
*ConnectionApi* | [**mass_delete_connection**](docs/ConnectionApi.md#mass_delete_connection) | **POST** /Connection/action/massDelete | Mass delete of Connection data
*ConnectionApi* | [**mass_update_connection**](docs/ConnectionApi.md#mass_update_connection) | **PUT** /Connection/action/massUpdate | Mass update of Connection data
*ConnectionApi* | [**remove_relation_for_connection**](docs/ConnectionApi.md#remove_relation_for_connection) | **DELETE** /Connection/{link}/relation | Remove relation for Connection
*ConnectionApi* | [**unfollow_connection**](docs/ConnectionApi.md#unfollow_connection) | **DELETE** /Connection/{id}/subscription | Unfollow the Connection stream
*ConnectionApi* | [**unlink_connection**](docs/ConnectionApi.md#unlink_connection) | **DELETE** /Connection/{id}/{link} | Unlink Connection from Entities
*ConnectionApi* | [**update_connection_item**](docs/ConnectionApi.md#update_connection_item) | **PUT** /Connection/{id} | Update a record of the Connection
*ContentApi* | [**add_relation_for_content**](docs/ContentApi.md#add_relation_for_content) | **POST** /Content/{link}/relation | Add relation for Content
*ContentApi* | [**create_content_item**](docs/ContentApi.md#create_content_item) | **POST** /Content | Create a record of the Content
*ContentApi* | [**delete_content_item**](docs/ContentApi.md#delete_content_item) | **DELETE** /Content/{id} | Delete a record of the Content
*ContentApi* | [**follow_content**](docs/ContentApi.md#follow_content) | **PUT** /Content/{id}/subscription | Follow the Content stream
*ContentApi* | [**get_content_item**](docs/ContentApi.md#get_content_item) | **GET** /Content/{id} | Returns a record of the Content
*ContentApi* | [**get_linked_items_for_content_item**](docs/ContentApi.md#get_linked_items_for_content_item) | **GET** /Content/{id}/{link} | Returns linked entities for the Content
*ContentApi* | [**get_list_of_content_items**](docs/ContentApi.md#get_list_of_content_items) | **GET** /Content | Returns a collection of Content records
*ContentApi* | [**link_content**](docs/ContentApi.md#link_content) | **POST** /Content/{id}/{link} | Link Content to Entities
*ContentApi* | [**mass_delete_content**](docs/ContentApi.md#mass_delete_content) | **POST** /Content/action/massDelete | Mass delete of Content data
*ContentApi* | [**mass_update_content**](docs/ContentApi.md#mass_update_content) | **PUT** /Content/action/massUpdate | Mass update of Content data
*ContentApi* | [**remove_relation_for_content**](docs/ContentApi.md#remove_relation_for_content) | **DELETE** /Content/{link}/relation | Remove relation for Content
*ContentApi* | [**unfollow_content**](docs/ContentApi.md#unfollow_content) | **DELETE** /Content/{id}/subscription | Unfollow the Content stream
*ContentApi* | [**unlink_content**](docs/ContentApi.md#unlink_content) | **DELETE** /Content/{id}/{link} | Unlink Content from Entities
*ContentApi* | [**update_content_item**](docs/ContentApi.md#update_content_item) | **PUT** /Content/{id} | Update a record of the Content
*ContentGroupApi* | [**add_relation_for_content_group**](docs/ContentGroupApi.md#add_relation_for_content_group) | **POST** /ContentGroup/{link}/relation | Add relation for ContentGroup
*ContentGroupApi* | [**create_content_group_item**](docs/ContentGroupApi.md#create_content_group_item) | **POST** /ContentGroup | Create a record of the ContentGroup
*ContentGroupApi* | [**delete_content_group_item**](docs/ContentGroupApi.md#delete_content_group_item) | **DELETE** /ContentGroup/{id} | Delete a record of the ContentGroup
*ContentGroupApi* | [**follow_content_group**](docs/ContentGroupApi.md#follow_content_group) | **PUT** /ContentGroup/{id}/subscription | Follow the ContentGroup stream
*ContentGroupApi* | [**get_content_group_item**](docs/ContentGroupApi.md#get_content_group_item) | **GET** /ContentGroup/{id} | Returns a record of the ContentGroup
*ContentGroupApi* | [**get_linked_items_for_content_group_item**](docs/ContentGroupApi.md#get_linked_items_for_content_group_item) | **GET** /ContentGroup/{id}/{link} | Returns linked entities for the ContentGroup
*ContentGroupApi* | [**get_list_of_content_group_items**](docs/ContentGroupApi.md#get_list_of_content_group_items) | **GET** /ContentGroup | Returns a collection of ContentGroup records
*ContentGroupApi* | [**link_content_group**](docs/ContentGroupApi.md#link_content_group) | **POST** /ContentGroup/{id}/{link} | Link ContentGroup to Entities
*ContentGroupApi* | [**mass_delete_content_group**](docs/ContentGroupApi.md#mass_delete_content_group) | **POST** /ContentGroup/action/massDelete | Mass delete of ContentGroup data
*ContentGroupApi* | [**mass_update_content_group**](docs/ContentGroupApi.md#mass_update_content_group) | **PUT** /ContentGroup/action/massUpdate | Mass update of ContentGroup data
*ContentGroupApi* | [**remove_relation_for_content_group**](docs/ContentGroupApi.md#remove_relation_for_content_group) | **DELETE** /ContentGroup/{link}/relation | Remove relation for ContentGroup
*ContentGroupApi* | [**unfollow_content_group**](docs/ContentGroupApi.md#unfollow_content_group) | **DELETE** /ContentGroup/{id}/subscription | Unfollow the ContentGroup stream
*ContentGroupApi* | [**unlink_content_group**](docs/ContentGroupApi.md#unlink_content_group) | **DELETE** /ContentGroup/{id}/{link} | Unlink ContentGroup from Entities
*ContentGroupApi* | [**update_content_group_item**](docs/ContentGroupApi.md#update_content_group_item) | **PUT** /ContentGroup/{id} | Update a record of the ContentGroup
*DashletApi* | [**get_dashlet_data**](docs/DashletApi.md#get_dashlet_data) | **GET** /Dashlet/{dashletName} | Get Dashlet data
*ExportConfiguratorItemApi* | [**add_relation_for_export_configurator_item**](docs/ExportConfiguratorItemApi.md#add_relation_for_export_configurator_item) | **POST** /ExportConfiguratorItem/{link}/relation | Add relation for ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**create_export_configurator_item_item**](docs/ExportConfiguratorItemApi.md#create_export_configurator_item_item) | **POST** /ExportConfiguratorItem | Create a record of the ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**delete_export_configurator_item_item**](docs/ExportConfiguratorItemApi.md#delete_export_configurator_item_item) | **DELETE** /ExportConfiguratorItem/{id} | Delete a record of the ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**follow_export_configurator_item**](docs/ExportConfiguratorItemApi.md#follow_export_configurator_item) | **PUT** /ExportConfiguratorItem/{id}/subscription | Follow the ExportConfiguratorItem stream
*ExportConfiguratorItemApi* | [**get_export_configurator_item_item**](docs/ExportConfiguratorItemApi.md#get_export_configurator_item_item) | **GET** /ExportConfiguratorItem/{id} | Returns a record of the ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**get_linked_items_for_export_configurator_item_item**](docs/ExportConfiguratorItemApi.md#get_linked_items_for_export_configurator_item_item) | **GET** /ExportConfiguratorItem/{id}/{link} | Returns linked entities for the ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**get_list_of_export_configurator_item_items**](docs/ExportConfiguratorItemApi.md#get_list_of_export_configurator_item_items) | **GET** /ExportConfiguratorItem | Returns a collection of ExportConfiguratorItem records
*ExportConfiguratorItemApi* | [**link_export_configurator_item**](docs/ExportConfiguratorItemApi.md#link_export_configurator_item) | **POST** /ExportConfiguratorItem/{id}/{link} | Link ExportConfiguratorItem to Entities
*ExportConfiguratorItemApi* | [**mass_delete_export_configurator_item**](docs/ExportConfiguratorItemApi.md#mass_delete_export_configurator_item) | **POST** /ExportConfiguratorItem/action/massDelete | Mass delete of ExportConfiguratorItem data
*ExportConfiguratorItemApi* | [**mass_update_export_configurator_item**](docs/ExportConfiguratorItemApi.md#mass_update_export_configurator_item) | **PUT** /ExportConfiguratorItem/action/massUpdate | Mass update of ExportConfiguratorItem data
*ExportConfiguratorItemApi* | [**remove_relation_for_export_configurator_item**](docs/ExportConfiguratorItemApi.md#remove_relation_for_export_configurator_item) | **DELETE** /ExportConfiguratorItem/{link}/relation | Remove relation for ExportConfiguratorItem
*ExportConfiguratorItemApi* | [**unfollow_export_configurator_item**](docs/ExportConfiguratorItemApi.md#unfollow_export_configurator_item) | **DELETE** /ExportConfiguratorItem/{id}/subscription | Unfollow the ExportConfiguratorItem stream
*ExportConfiguratorItemApi* | [**unlink_export_configurator_item**](docs/ExportConfiguratorItemApi.md#unlink_export_configurator_item) | **DELETE** /ExportConfiguratorItem/{id}/{link} | Unlink ExportConfiguratorItem from Entities
*ExportConfiguratorItemApi* | [**update_export_configurator_item_item**](docs/ExportConfiguratorItemApi.md#update_export_configurator_item_item) | **PUT** /ExportConfiguratorItem/{id} | Update a record of the ExportConfiguratorItem
*ExportFeedApi* | [**add_relation_for_export_feed**](docs/ExportFeedApi.md#add_relation_for_export_feed) | **POST** /ExportFeed/{link}/relation | Add relation for ExportFeed
*ExportFeedApi* | [**create_export_feed_item**](docs/ExportFeedApi.md#create_export_feed_item) | **POST** /ExportFeed | Create a record of the ExportFeed
*ExportFeedApi* | [**delete_export_feed_item**](docs/ExportFeedApi.md#delete_export_feed_item) | **DELETE** /ExportFeed/{id} | Delete a record of the ExportFeed
*ExportFeedApi* | [**export_channel**](docs/ExportFeedApi.md#export_channel) | **POST** /ExportFeed/action/exportChannel | Export channel data to file
*ExportFeedApi* | [**export_file**](docs/ExportFeedApi.md#export_file) | **POST** /ExportFeed/action/exportFile | Export data to file
*ExportFeedApi* | [**follow_export_feed**](docs/ExportFeedApi.md#follow_export_feed) | **PUT** /ExportFeed/{id}/subscription | Follow the ExportFeed stream
*ExportFeedApi* | [**get_export_feed_item**](docs/ExportFeedApi.md#get_export_feed_item) | **GET** /ExportFeed/{id} | Returns a record of the ExportFeed
*ExportFeedApi* | [**get_linked_items_for_export_feed_item**](docs/ExportFeedApi.md#get_linked_items_for_export_feed_item) | **GET** /ExportFeed/{id}/{link} | Returns linked entities for the ExportFeed
*ExportFeedApi* | [**get_list_of_export_feed_items**](docs/ExportFeedApi.md#get_list_of_export_feed_items) | **GET** /ExportFeed | Returns a collection of ExportFeed records
*ExportFeedApi* | [**link_export_feed**](docs/ExportFeedApi.md#link_export_feed) | **POST** /ExportFeed/{id}/{link} | Link ExportFeed to Entities
*ExportFeedApi* | [**mass_delete_export_feed**](docs/ExportFeedApi.md#mass_delete_export_feed) | **POST** /ExportFeed/action/massDelete | Mass delete of ExportFeed data
*ExportFeedApi* | [**mass_update_export_feed**](docs/ExportFeedApi.md#mass_update_export_feed) | **PUT** /ExportFeed/action/massUpdate | Mass update of ExportFeed data
*ExportFeedApi* | [**remove_relation_for_export_feed**](docs/ExportFeedApi.md#remove_relation_for_export_feed) | **DELETE** /ExportFeed/{link}/relation | Remove relation for ExportFeed
*ExportFeedApi* | [**unfollow_export_feed**](docs/ExportFeedApi.md#unfollow_export_feed) | **DELETE** /ExportFeed/{id}/subscription | Unfollow the ExportFeed stream
*ExportFeedApi* | [**unlink_export_feed**](docs/ExportFeedApi.md#unlink_export_feed) | **DELETE** /ExportFeed/{id}/{link} | Unlink ExportFeed from Entities
*ExportFeedApi* | [**update_export_feed_item**](docs/ExportFeedApi.md#update_export_feed_item) | **PUT** /ExportFeed/{id} | Update a record of the ExportFeed
*ExportJobApi* | [**add_relation_for_export_job**](docs/ExportJobApi.md#add_relation_for_export_job) | **POST** /ExportJob/{link}/relation | Add relation for ExportJob
*ExportJobApi* | [**create_export_job_item**](docs/ExportJobApi.md#create_export_job_item) | **POST** /ExportJob | Create a record of the ExportJob
*ExportJobApi* | [**delete_export_job_item**](docs/ExportJobApi.md#delete_export_job_item) | **DELETE** /ExportJob/{id} | Delete a record of the ExportJob
*ExportJobApi* | [**follow_export_job**](docs/ExportJobApi.md#follow_export_job) | **PUT** /ExportJob/{id}/subscription | Follow the ExportJob stream
*ExportJobApi* | [**get_export_job_item**](docs/ExportJobApi.md#get_export_job_item) | **GET** /ExportJob/{id} | Returns a record of the ExportJob
*ExportJobApi* | [**get_linked_items_for_export_job_item**](docs/ExportJobApi.md#get_linked_items_for_export_job_item) | **GET** /ExportJob/{id}/{link} | Returns linked entities for the ExportJob
*ExportJobApi* | [**get_list_of_export_job_items**](docs/ExportJobApi.md#get_list_of_export_job_items) | **GET** /ExportJob | Returns a collection of ExportJob records
*ExportJobApi* | [**link_export_job**](docs/ExportJobApi.md#link_export_job) | **POST** /ExportJob/{id}/{link} | Link ExportJob to Entities
*ExportJobApi* | [**mass_delete_export_job**](docs/ExportJobApi.md#mass_delete_export_job) | **POST** /ExportJob/action/massDelete | Mass delete of ExportJob data
*ExportJobApi* | [**mass_update_export_job**](docs/ExportJobApi.md#mass_update_export_job) | **PUT** /ExportJob/action/massUpdate | Mass update of ExportJob data
*ExportJobApi* | [**remove_relation_for_export_job**](docs/ExportJobApi.md#remove_relation_for_export_job) | **DELETE** /ExportJob/{link}/relation | Remove relation for ExportJob
*ExportJobApi* | [**unfollow_export_job**](docs/ExportJobApi.md#unfollow_export_job) | **DELETE** /ExportJob/{id}/subscription | Unfollow the ExportJob stream
*ExportJobApi* | [**unlink_export_job**](docs/ExportJobApi.md#unlink_export_job) | **DELETE** /ExportJob/{id}/{link} | Unlink ExportJob from Entities
*ExportJobApi* | [**update_export_job_item**](docs/ExportJobApi.md#update_export_job_item) | **PUT** /ExportJob/{id} | Update a record of the ExportJob
*ExtensibleEnumApi* | [**add_relation_for_extensible_enum**](docs/ExtensibleEnumApi.md#add_relation_for_extensible_enum) | **POST** /ExtensibleEnum/{link}/relation | Add relation for ExtensibleEnum
*ExtensibleEnumApi* | [**create_extensible_enum_item**](docs/ExtensibleEnumApi.md#create_extensible_enum_item) | **POST** /ExtensibleEnum | Create a record of the ExtensibleEnum
*ExtensibleEnumApi* | [**delete_extensible_enum_item**](docs/ExtensibleEnumApi.md#delete_extensible_enum_item) | **DELETE** /ExtensibleEnum/{id} | Delete a record of the ExtensibleEnum
*ExtensibleEnumApi* | [**follow_extensible_enum**](docs/ExtensibleEnumApi.md#follow_extensible_enum) | **PUT** /ExtensibleEnum/{id}/subscription | Follow the ExtensibleEnum stream
*ExtensibleEnumApi* | [**get_extensible_enum_item**](docs/ExtensibleEnumApi.md#get_extensible_enum_item) | **GET** /ExtensibleEnum/{id} | Returns a record of the ExtensibleEnum
*ExtensibleEnumApi* | [**get_linked_items_for_extensible_enum_item**](docs/ExtensibleEnumApi.md#get_linked_items_for_extensible_enum_item) | **GET** /ExtensibleEnum/{id}/{link} | Returns linked entities for the ExtensibleEnum
*ExtensibleEnumApi* | [**get_list_of_extensible_enum_items**](docs/ExtensibleEnumApi.md#get_list_of_extensible_enum_items) | **GET** /ExtensibleEnum | Returns a collection of ExtensibleEnum records
*ExtensibleEnumApi* | [**link_extensible_enum**](docs/ExtensibleEnumApi.md#link_extensible_enum) | **POST** /ExtensibleEnum/{id}/{link} | Link ExtensibleEnum to Entities
*ExtensibleEnumApi* | [**mass_delete_extensible_enum**](docs/ExtensibleEnumApi.md#mass_delete_extensible_enum) | **POST** /ExtensibleEnum/action/massDelete | Mass delete of ExtensibleEnum data
*ExtensibleEnumApi* | [**mass_update_extensible_enum**](docs/ExtensibleEnumApi.md#mass_update_extensible_enum) | **PUT** /ExtensibleEnum/action/massUpdate | Mass update of ExtensibleEnum data
*ExtensibleEnumApi* | [**remove_relation_for_extensible_enum**](docs/ExtensibleEnumApi.md#remove_relation_for_extensible_enum) | **DELETE** /ExtensibleEnum/{link}/relation | Remove relation for ExtensibleEnum
*ExtensibleEnumApi* | [**unfollow_extensible_enum**](docs/ExtensibleEnumApi.md#unfollow_extensible_enum) | **DELETE** /ExtensibleEnum/{id}/subscription | Unfollow the ExtensibleEnum stream
*ExtensibleEnumApi* | [**unlink_extensible_enum**](docs/ExtensibleEnumApi.md#unlink_extensible_enum) | **DELETE** /ExtensibleEnum/{id}/{link} | Unlink ExtensibleEnum from Entities
*ExtensibleEnumApi* | [**update_extensible_enum_item**](docs/ExtensibleEnumApi.md#update_extensible_enum_item) | **PUT** /ExtensibleEnum/{id} | Update a record of the ExtensibleEnum
*ExtensibleEnumOptionApi* | [**add_relation_for_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#add_relation_for_extensible_enum_option) | **POST** /ExtensibleEnumOption/{link}/relation | Add relation for ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**create_extensible_enum_option_item**](docs/ExtensibleEnumOptionApi.md#create_extensible_enum_option_item) | **POST** /ExtensibleEnumOption | Create a record of the ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**delete_extensible_enum_option_item**](docs/ExtensibleEnumOptionApi.md#delete_extensible_enum_option_item) | **DELETE** /ExtensibleEnumOption/{id} | Delete a record of the ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**follow_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#follow_extensible_enum_option) | **PUT** /ExtensibleEnumOption/{id}/subscription | Follow the ExtensibleEnumOption stream
*ExtensibleEnumOptionApi* | [**get_extensible_enum_option_item**](docs/ExtensibleEnumOptionApi.md#get_extensible_enum_option_item) | **GET** /ExtensibleEnumOption/{id} | Returns a record of the ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**get_linked_items_for_extensible_enum_option_item**](docs/ExtensibleEnumOptionApi.md#get_linked_items_for_extensible_enum_option_item) | **GET** /ExtensibleEnumOption/{id}/{link} | Returns linked entities for the ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**get_list_of_extensible_enum_option_items**](docs/ExtensibleEnumOptionApi.md#get_list_of_extensible_enum_option_items) | **GET** /ExtensibleEnumOption | Returns a collection of ExtensibleEnumOption records
*ExtensibleEnumOptionApi* | [**link_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#link_extensible_enum_option) | **POST** /ExtensibleEnumOption/{id}/{link} | Link ExtensibleEnumOption to Entities
*ExtensibleEnumOptionApi* | [**mass_delete_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#mass_delete_extensible_enum_option) | **POST** /ExtensibleEnumOption/action/massDelete | Mass delete of ExtensibleEnumOption data
*ExtensibleEnumOptionApi* | [**mass_update_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#mass_update_extensible_enum_option) | **PUT** /ExtensibleEnumOption/action/massUpdate | Mass update of ExtensibleEnumOption data
*ExtensibleEnumOptionApi* | [**remove_relation_for_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#remove_relation_for_extensible_enum_option) | **DELETE** /ExtensibleEnumOption/{link}/relation | Remove relation for ExtensibleEnumOption
*ExtensibleEnumOptionApi* | [**unfollow_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#unfollow_extensible_enum_option) | **DELETE** /ExtensibleEnumOption/{id}/subscription | Unfollow the ExtensibleEnumOption stream
*ExtensibleEnumOptionApi* | [**unlink_extensible_enum_option**](docs/ExtensibleEnumOptionApi.md#unlink_extensible_enum_option) | **DELETE** /ExtensibleEnumOption/{id}/{link} | Unlink ExtensibleEnumOption from Entities
*ExtensibleEnumOptionApi* | [**update_extensible_enum_option_item**](docs/ExtensibleEnumOptionApi.md#update_extensible_enum_option_item) | **PUT** /ExtensibleEnumOption/{id} | Update a record of the ExtensibleEnumOption
*ImportConfiguratorItemApi* | [**add_relation_for_import_configurator_item**](docs/ImportConfiguratorItemApi.md#add_relation_for_import_configurator_item) | **POST** /ImportConfiguratorItem/{link}/relation | Add relation for ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**create_import_configurator_item_item**](docs/ImportConfiguratorItemApi.md#create_import_configurator_item_item) | **POST** /ImportConfiguratorItem | Create a record of the ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**delete_import_configurator_item_item**](docs/ImportConfiguratorItemApi.md#delete_import_configurator_item_item) | **DELETE** /ImportConfiguratorItem/{id} | Delete a record of the ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**follow_import_configurator_item**](docs/ImportConfiguratorItemApi.md#follow_import_configurator_item) | **PUT** /ImportConfiguratorItem/{id}/subscription | Follow the ImportConfiguratorItem stream
*ImportConfiguratorItemApi* | [**get_import_configurator_item_item**](docs/ImportConfiguratorItemApi.md#get_import_configurator_item_item) | **GET** /ImportConfiguratorItem/{id} | Returns a record of the ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**get_linked_items_for_import_configurator_item_item**](docs/ImportConfiguratorItemApi.md#get_linked_items_for_import_configurator_item_item) | **GET** /ImportConfiguratorItem/{id}/{link} | Returns linked entities for the ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**get_list_of_import_configurator_item_items**](docs/ImportConfiguratorItemApi.md#get_list_of_import_configurator_item_items) | **GET** /ImportConfiguratorItem | Returns a collection of ImportConfiguratorItem records
*ImportConfiguratorItemApi* | [**link_import_configurator_item**](docs/ImportConfiguratorItemApi.md#link_import_configurator_item) | **POST** /ImportConfiguratorItem/{id}/{link} | Link ImportConfiguratorItem to Entities
*ImportConfiguratorItemApi* | [**mass_delete_import_configurator_item**](docs/ImportConfiguratorItemApi.md#mass_delete_import_configurator_item) | **POST** /ImportConfiguratorItem/action/massDelete | Mass delete of ImportConfiguratorItem data
*ImportConfiguratorItemApi* | [**mass_update_import_configurator_item**](docs/ImportConfiguratorItemApi.md#mass_update_import_configurator_item) | **PUT** /ImportConfiguratorItem/action/massUpdate | Mass update of ImportConfiguratorItem data
*ImportConfiguratorItemApi* | [**remove_relation_for_import_configurator_item**](docs/ImportConfiguratorItemApi.md#remove_relation_for_import_configurator_item) | **DELETE** /ImportConfiguratorItem/{link}/relation | Remove relation for ImportConfiguratorItem
*ImportConfiguratorItemApi* | [**unfollow_import_configurator_item**](docs/ImportConfiguratorItemApi.md#unfollow_import_configurator_item) | **DELETE** /ImportConfiguratorItem/{id}/subscription | Unfollow the ImportConfiguratorItem stream
*ImportConfiguratorItemApi* | [**unlink_import_configurator_item**](docs/ImportConfiguratorItemApi.md#unlink_import_configurator_item) | **DELETE** /ImportConfiguratorItem/{id}/{link} | Unlink ImportConfiguratorItem from Entities
*ImportConfiguratorItemApi* | [**update_import_configurator_item_item**](docs/ImportConfiguratorItemApi.md#update_import_configurator_item_item) | **PUT** /ImportConfiguratorItem/{id} | Update a record of the ImportConfiguratorItem
*ImportFeedApi* | [**add_relation_for_import_feed**](docs/ImportFeedApi.md#add_relation_for_import_feed) | **POST** /ImportFeed/{link}/relation | Add relation for ImportFeed
*ImportFeedApi* | [**create_import_feed_item**](docs/ImportFeedApi.md#create_import_feed_item) | **POST** /ImportFeed | Create a record of the ImportFeed
*ImportFeedApi* | [**delete_import_feed_item**](docs/ImportFeedApi.md#delete_import_feed_item) | **DELETE** /ImportFeed/{id} | Delete a record of the ImportFeed
*ImportFeedApi* | [**follow_import_feed**](docs/ImportFeedApi.md#follow_import_feed) | **PUT** /ImportFeed/{id}/subscription | Follow the ImportFeed stream
*ImportFeedApi* | [**get_import_feed_item**](docs/ImportFeedApi.md#get_import_feed_item) | **GET** /ImportFeed/{id} | Returns a record of the ImportFeed
*ImportFeedApi* | [**get_linked_items_for_import_feed_item**](docs/ImportFeedApi.md#get_linked_items_for_import_feed_item) | **GET** /ImportFeed/{id}/{link} | Returns linked entities for the ImportFeed
*ImportFeedApi* | [**get_list_of_import_feed_items**](docs/ImportFeedApi.md#get_list_of_import_feed_items) | **GET** /ImportFeed | Returns a collection of ImportFeed records
*ImportFeedApi* | [**link_import_feed**](docs/ImportFeedApi.md#link_import_feed) | **POST** /ImportFeed/{id}/{link} | Link ImportFeed to Entities
*ImportFeedApi* | [**mass_delete_import_feed**](docs/ImportFeedApi.md#mass_delete_import_feed) | **POST** /ImportFeed/action/massDelete | Mass delete of ImportFeed data
*ImportFeedApi* | [**mass_update_import_feed**](docs/ImportFeedApi.md#mass_update_import_feed) | **PUT** /ImportFeed/action/massUpdate | Mass update of ImportFeed data
*ImportFeedApi* | [**remove_relation_for_import_feed**](docs/ImportFeedApi.md#remove_relation_for_import_feed) | **DELETE** /ImportFeed/{link}/relation | Remove relation for ImportFeed
*ImportFeedApi* | [**run_import**](docs/ImportFeedApi.md#run_import) | **POST** /ImportFeed/action/runImport | Run import
*ImportFeedApi* | [**unfollow_import_feed**](docs/ImportFeedApi.md#unfollow_import_feed) | **DELETE** /ImportFeed/{id}/subscription | Unfollow the ImportFeed stream
*ImportFeedApi* | [**unlink_import_feed**](docs/ImportFeedApi.md#unlink_import_feed) | **DELETE** /ImportFeed/{id}/{link} | Unlink ImportFeed from Entities
*ImportFeedApi* | [**update_import_feed_item**](docs/ImportFeedApi.md#update_import_feed_item) | **PUT** /ImportFeed/{id} | Update a record of the ImportFeed
*ImportJobApi* | [**add_relation_for_import_job**](docs/ImportJobApi.md#add_relation_for_import_job) | **POST** /ImportJob/{link}/relation | Add relation for ImportJob
*ImportJobApi* | [**create_import_job_item**](docs/ImportJobApi.md#create_import_job_item) | **POST** /ImportJob | Create a record of the ImportJob
*ImportJobApi* | [**delete_import_job_item**](docs/ImportJobApi.md#delete_import_job_item) | **DELETE** /ImportJob/{id} | Delete a record of the ImportJob
*ImportJobApi* | [**follow_import_job**](docs/ImportJobApi.md#follow_import_job) | **PUT** /ImportJob/{id}/subscription | Follow the ImportJob stream
*ImportJobApi* | [**get_import_job_item**](docs/ImportJobApi.md#get_import_job_item) | **GET** /ImportJob/{id} | Returns a record of the ImportJob
*ImportJobApi* | [**get_linked_items_for_import_job_item**](docs/ImportJobApi.md#get_linked_items_for_import_job_item) | **GET** /ImportJob/{id}/{link} | Returns linked entities for the ImportJob
*ImportJobApi* | [**get_list_of_import_job_items**](docs/ImportJobApi.md#get_list_of_import_job_items) | **GET** /ImportJob | Returns a collection of ImportJob records
*ImportJobApi* | [**link_import_job**](docs/ImportJobApi.md#link_import_job) | **POST** /ImportJob/{id}/{link} | Link ImportJob to Entities
*ImportJobApi* | [**mass_delete_import_job**](docs/ImportJobApi.md#mass_delete_import_job) | **POST** /ImportJob/action/massDelete | Mass delete of ImportJob data
*ImportJobApi* | [**mass_update_import_job**](docs/ImportJobApi.md#mass_update_import_job) | **PUT** /ImportJob/action/massUpdate | Mass update of ImportJob data
*ImportJobApi* | [**remove_relation_for_import_job**](docs/ImportJobApi.md#remove_relation_for_import_job) | **DELETE** /ImportJob/{link}/relation | Remove relation for ImportJob
*ImportJobApi* | [**unfollow_import_job**](docs/ImportJobApi.md#unfollow_import_job) | **DELETE** /ImportJob/{id}/subscription | Unfollow the ImportJob stream
*ImportJobApi* | [**unlink_import_job**](docs/ImportJobApi.md#unlink_import_job) | **DELETE** /ImportJob/{id}/{link} | Unlink ImportJob from Entities
*ImportJobApi* | [**update_import_job_item**](docs/ImportJobApi.md#update_import_job_item) | **PUT** /ImportJob/{id} | Update a record of the ImportJob
*ImportJobLogApi* | [**add_relation_for_import_job_log**](docs/ImportJobLogApi.md#add_relation_for_import_job_log) | **POST** /ImportJobLog/{link}/relation | Add relation for ImportJobLog
*ImportJobLogApi* | [**create_import_job_log_item**](docs/ImportJobLogApi.md#create_import_job_log_item) | **POST** /ImportJobLog | Create a record of the ImportJobLog
*ImportJobLogApi* | [**delete_import_job_log_item**](docs/ImportJobLogApi.md#delete_import_job_log_item) | **DELETE** /ImportJobLog/{id} | Delete a record of the ImportJobLog
*ImportJobLogApi* | [**follow_import_job_log**](docs/ImportJobLogApi.md#follow_import_job_log) | **PUT** /ImportJobLog/{id}/subscription | Follow the ImportJobLog stream
*ImportJobLogApi* | [**get_import_job_log_item**](docs/ImportJobLogApi.md#get_import_job_log_item) | **GET** /ImportJobLog/{id} | Returns a record of the ImportJobLog
*ImportJobLogApi* | [**get_linked_items_for_import_job_log_item**](docs/ImportJobLogApi.md#get_linked_items_for_import_job_log_item) | **GET** /ImportJobLog/{id}/{link} | Returns linked entities for the ImportJobLog
*ImportJobLogApi* | [**get_list_of_import_job_log_items**](docs/ImportJobLogApi.md#get_list_of_import_job_log_items) | **GET** /ImportJobLog | Returns a collection of ImportJobLog records
*ImportJobLogApi* | [**link_import_job_log**](docs/ImportJobLogApi.md#link_import_job_log) | **POST** /ImportJobLog/{id}/{link} | Link ImportJobLog to Entities
*ImportJobLogApi* | [**mass_delete_import_job_log**](docs/ImportJobLogApi.md#mass_delete_import_job_log) | **POST** /ImportJobLog/action/massDelete | Mass delete of ImportJobLog data
*ImportJobLogApi* | [**mass_update_import_job_log**](docs/ImportJobLogApi.md#mass_update_import_job_log) | **PUT** /ImportJobLog/action/massUpdate | Mass update of ImportJobLog data
*ImportJobLogApi* | [**remove_relation_for_import_job_log**](docs/ImportJobLogApi.md#remove_relation_for_import_job_log) | **DELETE** /ImportJobLog/{link}/relation | Remove relation for ImportJobLog
*ImportJobLogApi* | [**unfollow_import_job_log**](docs/ImportJobLogApi.md#unfollow_import_job_log) | **DELETE** /ImportJobLog/{id}/subscription | Unfollow the ImportJobLog stream
*ImportJobLogApi* | [**unlink_import_job_log**](docs/ImportJobLogApi.md#unlink_import_job_log) | **DELETE** /ImportJobLog/{id}/{link} | Unlink ImportJobLog from Entities
*ImportJobLogApi* | [**update_import_job_log_item**](docs/ImportJobLogApi.md#update_import_job_log_item) | **PUT** /ImportJobLog/{id} | Update a record of the ImportJobLog
*JobApi* | [**add_relation_for_job**](docs/JobApi.md#add_relation_for_job) | **POST** /Job/{link}/relation | Add relation for Job
*JobApi* | [**create_job_item**](docs/JobApi.md#create_job_item) | **POST** /Job | Create a record of the Job
*JobApi* | [**delete_job_item**](docs/JobApi.md#delete_job_item) | **DELETE** /Job/{id} | Delete a record of the Job
*JobApi* | [**follow_job**](docs/JobApi.md#follow_job) | **PUT** /Job/{id}/subscription | Follow the Job stream
*JobApi* | [**get_job_item**](docs/JobApi.md#get_job_item) | **GET** /Job/{id} | Returns a record of the Job
*JobApi* | [**get_linked_items_for_job_item**](docs/JobApi.md#get_linked_items_for_job_item) | **GET** /Job/{id}/{link} | Returns linked entities for the Job
*JobApi* | [**get_list_of_job_items**](docs/JobApi.md#get_list_of_job_items) | **GET** /Job | Returns a collection of Job records
*JobApi* | [**link_job**](docs/JobApi.md#link_job) | **POST** /Job/{id}/{link} | Link Job to Entities
*JobApi* | [**mass_delete_job**](docs/JobApi.md#mass_delete_job) | **POST** /Job/action/massDelete | Mass delete of Job data
*JobApi* | [**mass_update_job**](docs/JobApi.md#mass_update_job) | **PUT** /Job/action/massUpdate | Mass update of Job data
*JobApi* | [**remove_relation_for_job**](docs/JobApi.md#remove_relation_for_job) | **DELETE** /Job/{link}/relation | Remove relation for Job
*JobApi* | [**unfollow_job**](docs/JobApi.md#unfollow_job) | **DELETE** /Job/{id}/subscription | Unfollow the Job stream
*JobApi* | [**unlink_job**](docs/JobApi.md#unlink_job) | **DELETE** /Job/{id}/{link} | Unlink Job from Entities
*JobApi* | [**update_job_item**](docs/JobApi.md#update_job_item) | **PUT** /Job/{id} | Update a record of the Job
*LibraryApi* | [**add_relation_for_library**](docs/LibraryApi.md#add_relation_for_library) | **POST** /Library/{link}/relation | Add relation for Library
*LibraryApi* | [**create_library_item**](docs/LibraryApi.md#create_library_item) | **POST** /Library | Create a record of the Library
*LibraryApi* | [**delete_library_item**](docs/LibraryApi.md#delete_library_item) | **DELETE** /Library/{id} | Delete a record of the Library
*LibraryApi* | [**follow_library**](docs/LibraryApi.md#follow_library) | **PUT** /Library/{id}/subscription | Follow the Library stream
*LibraryApi* | [**get_library_item**](docs/LibraryApi.md#get_library_item) | **GET** /Library/{id} | Returns a record of the Library
*LibraryApi* | [**get_linked_items_for_library_item**](docs/LibraryApi.md#get_linked_items_for_library_item) | **GET** /Library/{id}/{link} | Returns linked entities for the Library
*LibraryApi* | [**get_list_of_library_items**](docs/LibraryApi.md#get_list_of_library_items) | **GET** /Library | Returns a collection of Library records
*LibraryApi* | [**link_library**](docs/LibraryApi.md#link_library) | **POST** /Library/{id}/{link} | Link Library to Entities
*LibraryApi* | [**mass_delete_library**](docs/LibraryApi.md#mass_delete_library) | **POST** /Library/action/massDelete | Mass delete of Library data
*LibraryApi* | [**mass_update_library**](docs/LibraryApi.md#mass_update_library) | **PUT** /Library/action/massUpdate | Mass update of Library data
*LibraryApi* | [**remove_relation_for_library**](docs/LibraryApi.md#remove_relation_for_library) | **DELETE** /Library/{link}/relation | Remove relation for Library
*LibraryApi* | [**unfollow_library**](docs/LibraryApi.md#unfollow_library) | **DELETE** /Library/{id}/subscription | Unfollow the Library stream
*LibraryApi* | [**unlink_library**](docs/LibraryApi.md#unlink_library) | **DELETE** /Library/{id}/{link} | Unlink Library from Entities
*LibraryApi* | [**update_library_item**](docs/LibraryApi.md#update_library_item) | **PUT** /Library/{id} | Update a record of the Library
*LocaleApi* | [**add_relation_for_locale**](docs/LocaleApi.md#add_relation_for_locale) | **POST** /Locale/{link}/relation | Add relation for Locale
*LocaleApi* | [**create_locale_item**](docs/LocaleApi.md#create_locale_item) | **POST** /Locale | Create a record of the Locale
*LocaleApi* | [**delete_locale_item**](docs/LocaleApi.md#delete_locale_item) | **DELETE** /Locale/{id} | Delete a record of the Locale
*LocaleApi* | [**follow_locale**](docs/LocaleApi.md#follow_locale) | **PUT** /Locale/{id}/subscription | Follow the Locale stream
*LocaleApi* | [**get_linked_items_for_locale_item**](docs/LocaleApi.md#get_linked_items_for_locale_item) | **GET** /Locale/{id}/{link} | Returns linked entities for the Locale
*LocaleApi* | [**get_list_of_locale_items**](docs/LocaleApi.md#get_list_of_locale_items) | **GET** /Locale | Returns a collection of Locale records
*LocaleApi* | [**get_locale_item**](docs/LocaleApi.md#get_locale_item) | **GET** /Locale/{id} | Returns a record of the Locale
*LocaleApi* | [**link_locale**](docs/LocaleApi.md#link_locale) | **POST** /Locale/{id}/{link} | Link Locale to Entities
*LocaleApi* | [**mass_delete_locale**](docs/LocaleApi.md#mass_delete_locale) | **POST** /Locale/action/massDelete | Mass delete of Locale data
*LocaleApi* | [**mass_update_locale**](docs/LocaleApi.md#mass_update_locale) | **PUT** /Locale/action/massUpdate | Mass update of Locale data
*LocaleApi* | [**remove_relation_for_locale**](docs/LocaleApi.md#remove_relation_for_locale) | **DELETE** /Locale/{link}/relation | Remove relation for Locale
*LocaleApi* | [**unfollow_locale**](docs/LocaleApi.md#unfollow_locale) | **DELETE** /Locale/{id}/subscription | Unfollow the Locale stream
*LocaleApi* | [**unlink_locale**](docs/LocaleApi.md#unlink_locale) | **DELETE** /Locale/{id}/{link} | Unlink Locale from Entities
*LocaleApi* | [**update_locale_item**](docs/LocaleApi.md#update_locale_item) | **PUT** /Locale/{id} | Update a record of the Locale
*MassActionsApi* | [**upsert**](docs/MassActionsApi.md#upsert) | **POST** /MassActions/action/upsert | Bulk create and bulk update.
*MeasureApi* | [**add_relation_for_measure**](docs/MeasureApi.md#add_relation_for_measure) | **POST** /Measure/{link}/relation | Add relation for Measure
*MeasureApi* | [**create_measure_item**](docs/MeasureApi.md#create_measure_item) | **POST** /Measure | Create a record of the Measure
*MeasureApi* | [**delete_measure_item**](docs/MeasureApi.md#delete_measure_item) | **DELETE** /Measure/{id} | Delete a record of the Measure
*MeasureApi* | [**follow_measure**](docs/MeasureApi.md#follow_measure) | **PUT** /Measure/{id}/subscription | Follow the Measure stream
*MeasureApi* | [**get_linked_items_for_measure_item**](docs/MeasureApi.md#get_linked_items_for_measure_item) | **GET** /Measure/{id}/{link} | Returns linked entities for the Measure
*MeasureApi* | [**get_list_of_measure_items**](docs/MeasureApi.md#get_list_of_measure_items) | **GET** /Measure | Returns a collection of Measure records
*MeasureApi* | [**get_measure_item**](docs/MeasureApi.md#get_measure_item) | **GET** /Measure/{id} | Returns a record of the Measure
*MeasureApi* | [**link_measure**](docs/MeasureApi.md#link_measure) | **POST** /Measure/{id}/{link} | Link Measure to Entities
*MeasureApi* | [**mass_delete_measure**](docs/MeasureApi.md#mass_delete_measure) | **POST** /Measure/action/massDelete | Mass delete of Measure data
*MeasureApi* | [**mass_update_measure**](docs/MeasureApi.md#mass_update_measure) | **PUT** /Measure/action/massUpdate | Mass update of Measure data
*MeasureApi* | [**remove_relation_for_measure**](docs/MeasureApi.md#remove_relation_for_measure) | **DELETE** /Measure/{link}/relation | Remove relation for Measure
*MeasureApi* | [**unfollow_measure**](docs/MeasureApi.md#unfollow_measure) | **DELETE** /Measure/{id}/subscription | Unfollow the Measure stream
*MeasureApi* | [**unlink_measure**](docs/MeasureApi.md#unlink_measure) | **DELETE** /Measure/{id}/{link} | Unlink Measure from Entities
*MeasureApi* | [**update_measure_item**](docs/MeasureApi.md#update_measure_item) | **PUT** /Measure/{id} | Update a record of the Measure
*NoteApi* | [**add_relation_for_note**](docs/NoteApi.md#add_relation_for_note) | **POST** /Note/{link}/relation | Add relation for Note
*NoteApi* | [**create_note_item**](docs/NoteApi.md#create_note_item) | **POST** /Note | Create a record of the Note
*NoteApi* | [**delete_note_item**](docs/NoteApi.md#delete_note_item) | **DELETE** /Note/{id} | Delete a record of the Note
*NoteApi* | [**follow_note**](docs/NoteApi.md#follow_note) | **PUT** /Note/{id}/subscription | Follow the Note stream
*NoteApi* | [**get_linked_items_for_note_item**](docs/NoteApi.md#get_linked_items_for_note_item) | **GET** /Note/{id}/{link} | Returns linked entities for the Note
*NoteApi* | [**get_list_of_note_items**](docs/NoteApi.md#get_list_of_note_items) | **GET** /Note | Returns a collection of Note records
*NoteApi* | [**get_note_item**](docs/NoteApi.md#get_note_item) | **GET** /Note/{id} | Returns a record of the Note
*NoteApi* | [**link_note**](docs/NoteApi.md#link_note) | **POST** /Note/{id}/{link} | Link Note to Entities
*NoteApi* | [**mass_delete_note**](docs/NoteApi.md#mass_delete_note) | **POST** /Note/action/massDelete | Mass delete of Note data
*NoteApi* | [**mass_update_note**](docs/NoteApi.md#mass_update_note) | **PUT** /Note/action/massUpdate | Mass update of Note data
*NoteApi* | [**remove_relation_for_note**](docs/NoteApi.md#remove_relation_for_note) | **DELETE** /Note/{link}/relation | Remove relation for Note
*NoteApi* | [**unfollow_note**](docs/NoteApi.md#unfollow_note) | **DELETE** /Note/{id}/subscription | Unfollow the Note stream
*NoteApi* | [**unlink_note**](docs/NoteApi.md#unlink_note) | **DELETE** /Note/{id}/{link} | Unlink Note from Entities
*NoteApi* | [**update_note_item**](docs/NoteApi.md#update_note_item) | **PUT** /Note/{id} | Update a record of the Note
*NotificationApi* | [**add_relation_for_notification**](docs/NotificationApi.md#add_relation_for_notification) | **POST** /Notification/{link}/relation | Add relation for Notification
*NotificationApi* | [**create_notification_item**](docs/NotificationApi.md#create_notification_item) | **POST** /Notification | Create a record of the Notification
*NotificationApi* | [**delete_notification_item**](docs/NotificationApi.md#delete_notification_item) | **DELETE** /Notification/{id} | Delete a record of the Notification
*NotificationApi* | [**follow_notification**](docs/NotificationApi.md#follow_notification) | **PUT** /Notification/{id}/subscription | Follow the Notification stream
*NotificationApi* | [**get_linked_items_for_notification_item**](docs/NotificationApi.md#get_linked_items_for_notification_item) | **GET** /Notification/{id}/{link} | Returns linked entities for the Notification
*NotificationApi* | [**get_list_of_notification_items**](docs/NotificationApi.md#get_list_of_notification_items) | **GET** /Notification | Returns a collection of Notification records
*NotificationApi* | [**get_notification_item**](docs/NotificationApi.md#get_notification_item) | **GET** /Notification/{id} | Returns a record of the Notification
*NotificationApi* | [**link_notification**](docs/NotificationApi.md#link_notification) | **POST** /Notification/{id}/{link} | Link Notification to Entities
*NotificationApi* | [**mass_delete_notification**](docs/NotificationApi.md#mass_delete_notification) | **POST** /Notification/action/massDelete | Mass delete of Notification data
*NotificationApi* | [**mass_update_notification**](docs/NotificationApi.md#mass_update_notification) | **PUT** /Notification/action/massUpdate | Mass update of Notification data
*NotificationApi* | [**remove_relation_for_notification**](docs/NotificationApi.md#remove_relation_for_notification) | **DELETE** /Notification/{link}/relation | Remove relation for Notification
*NotificationApi* | [**unfollow_notification**](docs/NotificationApi.md#unfollow_notification) | **DELETE** /Notification/{id}/subscription | Unfollow the Notification stream
*NotificationApi* | [**unlink_notification**](docs/NotificationApi.md#unlink_notification) | **DELETE** /Notification/{id}/{link} | Unlink Notification from Entities
*NotificationApi* | [**update_notification_item**](docs/NotificationApi.md#update_notification_item) | **PUT** /Notification/{id} | Update a record of the Notification
*PackagingApi* | [**add_relation_for_packaging**](docs/PackagingApi.md#add_relation_for_packaging) | **POST** /Packaging/{link}/relation | Add relation for Packaging
*PackagingApi* | [**create_packaging_item**](docs/PackagingApi.md#create_packaging_item) | **POST** /Packaging | Create a record of the Packaging
*PackagingApi* | [**delete_packaging_item**](docs/PackagingApi.md#delete_packaging_item) | **DELETE** /Packaging/{id} | Delete a record of the Packaging
*PackagingApi* | [**follow_packaging**](docs/PackagingApi.md#follow_packaging) | **PUT** /Packaging/{id}/subscription | Follow the Packaging stream
*PackagingApi* | [**get_linked_items_for_packaging_item**](docs/PackagingApi.md#get_linked_items_for_packaging_item) | **GET** /Packaging/{id}/{link} | Returns linked entities for the Packaging
*PackagingApi* | [**get_list_of_packaging_items**](docs/PackagingApi.md#get_list_of_packaging_items) | **GET** /Packaging | Returns a collection of Packaging records
*PackagingApi* | [**get_packaging_item**](docs/PackagingApi.md#get_packaging_item) | **GET** /Packaging/{id} | Returns a record of the Packaging
*PackagingApi* | [**link_packaging**](docs/PackagingApi.md#link_packaging) | **POST** /Packaging/{id}/{link} | Link Packaging to Entities
*PackagingApi* | [**mass_delete_packaging**](docs/PackagingApi.md#mass_delete_packaging) | **POST** /Packaging/action/massDelete | Mass delete of Packaging data
*PackagingApi* | [**mass_update_packaging**](docs/PackagingApi.md#mass_update_packaging) | **PUT** /Packaging/action/massUpdate | Mass update of Packaging data
*PackagingApi* | [**remove_relation_for_packaging**](docs/PackagingApi.md#remove_relation_for_packaging) | **DELETE** /Packaging/{link}/relation | Remove relation for Packaging
*PackagingApi* | [**unfollow_packaging**](docs/PackagingApi.md#unfollow_packaging) | **DELETE** /Packaging/{id}/subscription | Unfollow the Packaging stream
*PackagingApi* | [**unlink_packaging**](docs/PackagingApi.md#unlink_packaging) | **DELETE** /Packaging/{id}/{link} | Unlink Packaging from Entities
*PackagingApi* | [**update_packaging_item**](docs/PackagingApi.md#update_packaging_item) | **PUT** /Packaging/{id} | Update a record of the Packaging
*PortalApi* | [**add_relation_for_portal**](docs/PortalApi.md#add_relation_for_portal) | **POST** /Portal/{link}/relation | Add relation for Portal
*PortalApi* | [**create_portal_item**](docs/PortalApi.md#create_portal_item) | **POST** /Portal | Create a record of the Portal
*PortalApi* | [**delete_portal_item**](docs/PortalApi.md#delete_portal_item) | **DELETE** /Portal/{id} | Delete a record of the Portal
*PortalApi* | [**follow_portal**](docs/PortalApi.md#follow_portal) | **PUT** /Portal/{id}/subscription | Follow the Portal stream
*PortalApi* | [**get_linked_items_for_portal_item**](docs/PortalApi.md#get_linked_items_for_portal_item) | **GET** /Portal/{id}/{link} | Returns linked entities for the Portal
*PortalApi* | [**get_list_of_portal_items**](docs/PortalApi.md#get_list_of_portal_items) | **GET** /Portal | Returns a collection of Portal records
*PortalApi* | [**get_portal_item**](docs/PortalApi.md#get_portal_item) | **GET** /Portal/{id} | Returns a record of the Portal
*PortalApi* | [**link_portal**](docs/PortalApi.md#link_portal) | **POST** /Portal/{id}/{link} | Link Portal to Entities
*PortalApi* | [**mass_delete_portal**](docs/PortalApi.md#mass_delete_portal) | **POST** /Portal/action/massDelete | Mass delete of Portal data
*PortalApi* | [**mass_update_portal**](docs/PortalApi.md#mass_update_portal) | **PUT** /Portal/action/massUpdate | Mass update of Portal data
*PortalApi* | [**remove_relation_for_portal**](docs/PortalApi.md#remove_relation_for_portal) | **DELETE** /Portal/{link}/relation | Remove relation for Portal
*PortalApi* | [**unfollow_portal**](docs/PortalApi.md#unfollow_portal) | **DELETE** /Portal/{id}/subscription | Unfollow the Portal stream
*PortalApi* | [**unlink_portal**](docs/PortalApi.md#unlink_portal) | **DELETE** /Portal/{id}/{link} | Unlink Portal from Entities
*PortalApi* | [**update_portal_item**](docs/PortalApi.md#update_portal_item) | **PUT** /Portal/{id} | Update a record of the Portal
*PreferencesApi* | [**add_relation_for_preferences**](docs/PreferencesApi.md#add_relation_for_preferences) | **POST** /Preferences/{link}/relation | Add relation for Preferences
*PreferencesApi* | [**create_preferences_item**](docs/PreferencesApi.md#create_preferences_item) | **POST** /Preferences | Create a record of the Preferences
*PreferencesApi* | [**delete_preferences_item**](docs/PreferencesApi.md#delete_preferences_item) | **DELETE** /Preferences/{id} | Delete a record of the Preferences
*PreferencesApi* | [**follow_preferences**](docs/PreferencesApi.md#follow_preferences) | **PUT** /Preferences/{id}/subscription | Follow the Preferences stream
*PreferencesApi* | [**get_linked_items_for_preferences_item**](docs/PreferencesApi.md#get_linked_items_for_preferences_item) | **GET** /Preferences/{id}/{link} | Returns linked entities for the Preferences
*PreferencesApi* | [**get_list_of_preferences_items**](docs/PreferencesApi.md#get_list_of_preferences_items) | **GET** /Preferences | Returns a collection of Preferences records
*PreferencesApi* | [**get_preferences_item**](docs/PreferencesApi.md#get_preferences_item) | **GET** /Preferences/{id} | Returns a record of the Preferences
*PreferencesApi* | [**link_preferences**](docs/PreferencesApi.md#link_preferences) | **POST** /Preferences/{id}/{link} | Link Preferences to Entities
*PreferencesApi* | [**mass_delete_preferences**](docs/PreferencesApi.md#mass_delete_preferences) | **POST** /Preferences/action/massDelete | Mass delete of Preferences data
*PreferencesApi* | [**mass_update_preferences**](docs/PreferencesApi.md#mass_update_preferences) | **PUT** /Preferences/action/massUpdate | Mass update of Preferences data
*PreferencesApi* | [**remove_relation_for_preferences**](docs/PreferencesApi.md#remove_relation_for_preferences) | **DELETE** /Preferences/{link}/relation | Remove relation for Preferences
*PreferencesApi* | [**unfollow_preferences**](docs/PreferencesApi.md#unfollow_preferences) | **DELETE** /Preferences/{id}/subscription | Unfollow the Preferences stream
*PreferencesApi* | [**unlink_preferences**](docs/PreferencesApi.md#unlink_preferences) | **DELETE** /Preferences/{id}/{link} | Unlink Preferences from Entities
*PreferencesApi* | [**update_preferences_item**](docs/PreferencesApi.md#update_preferences_item) | **PUT** /Preferences/{id} | Update a record of the Preferences
*ProductApi* | [**add_relation_for_product**](docs/ProductApi.md#add_relation_for_product) | **POST** /Product/{link}/relation | Add relation for Product
*ProductApi* | [**create_product_item**](docs/ProductApi.md#create_product_item) | **POST** /Product | Create a record of the Product
*ProductApi* | [**delete_product_item**](docs/ProductApi.md#delete_product_item) | **DELETE** /Product/{id} | Delete a record of the Product
*ProductApi* | [**follow_product**](docs/ProductApi.md#follow_product) | **PUT** /Product/{id}/subscription | Follow the Product stream
*ProductApi* | [**get_linked_items_for_product_item**](docs/ProductApi.md#get_linked_items_for_product_item) | **GET** /Product/{id}/{link} | Returns linked entities for the Product
*ProductApi* | [**get_list_of_product_items**](docs/ProductApi.md#get_list_of_product_items) | **GET** /Product | Returns a collection of Product records
*ProductApi* | [**get_product_item**](docs/ProductApi.md#get_product_item) | **GET** /Product/{id} | Returns a record of the Product
*ProductApi* | [**link_product**](docs/ProductApi.md#link_product) | **POST** /Product/{id}/{link} | Link Product to Entities
*ProductApi* | [**mass_delete_product**](docs/ProductApi.md#mass_delete_product) | **POST** /Product/action/massDelete | Mass delete of Product data
*ProductApi* | [**mass_update_product**](docs/ProductApi.md#mass_update_product) | **PUT** /Product/action/massUpdate | Mass update of Product data
*ProductApi* | [**remove_relation_for_product**](docs/ProductApi.md#remove_relation_for_product) | **DELETE** /Product/{link}/relation | Remove relation for Product
*ProductApi* | [**unfollow_product**](docs/ProductApi.md#unfollow_product) | **DELETE** /Product/{id}/subscription | Unfollow the Product stream
*ProductApi* | [**unlink_product**](docs/ProductApi.md#unlink_product) | **DELETE** /Product/{id}/{link} | Unlink Product from Entities
*ProductApi* | [**update_product_item**](docs/ProductApi.md#update_product_item) | **PUT** /Product/{id} | Update a record of the Product
*ProductAssetApi* | [**add_relation_for_product_asset**](docs/ProductAssetApi.md#add_relation_for_product_asset) | **POST** /ProductAsset/{link}/relation | Add relation for ProductAsset
*ProductAssetApi* | [**create_product_asset_item**](docs/ProductAssetApi.md#create_product_asset_item) | **POST** /ProductAsset | Create a record of the ProductAsset
*ProductAssetApi* | [**delete_product_asset_item**](docs/ProductAssetApi.md#delete_product_asset_item) | **DELETE** /ProductAsset/{id} | Delete a record of the ProductAsset
*ProductAssetApi* | [**follow_product_asset**](docs/ProductAssetApi.md#follow_product_asset) | **PUT** /ProductAsset/{id}/subscription | Follow the ProductAsset stream
*ProductAssetApi* | [**get_linked_items_for_product_asset_item**](docs/ProductAssetApi.md#get_linked_items_for_product_asset_item) | **GET** /ProductAsset/{id}/{link} | Returns linked entities for the ProductAsset
*ProductAssetApi* | [**get_list_of_product_asset_items**](docs/ProductAssetApi.md#get_list_of_product_asset_items) | **GET** /ProductAsset | Returns a collection of ProductAsset records
*ProductAssetApi* | [**get_product_asset_item**](docs/ProductAssetApi.md#get_product_asset_item) | **GET** /ProductAsset/{id} | Returns a record of the ProductAsset
*ProductAssetApi* | [**link_product_asset**](docs/ProductAssetApi.md#link_product_asset) | **POST** /ProductAsset/{id}/{link} | Link ProductAsset to Entities
*ProductAssetApi* | [**mass_delete_product_asset**](docs/ProductAssetApi.md#mass_delete_product_asset) | **POST** /ProductAsset/action/massDelete | Mass delete of ProductAsset data
*ProductAssetApi* | [**mass_update_product_asset**](docs/ProductAssetApi.md#mass_update_product_asset) | **PUT** /ProductAsset/action/massUpdate | Mass update of ProductAsset data
*ProductAssetApi* | [**remove_relation_for_product_asset**](docs/ProductAssetApi.md#remove_relation_for_product_asset) | **DELETE** /ProductAsset/{link}/relation | Remove relation for ProductAsset
*ProductAssetApi* | [**unfollow_product_asset**](docs/ProductAssetApi.md#unfollow_product_asset) | **DELETE** /ProductAsset/{id}/subscription | Unfollow the ProductAsset stream
*ProductAssetApi* | [**unlink_product_asset**](docs/ProductAssetApi.md#unlink_product_asset) | **DELETE** /ProductAsset/{id}/{link} | Unlink ProductAsset from Entities
*ProductAssetApi* | [**update_product_asset_item**](docs/ProductAssetApi.md#update_product_asset_item) | **PUT** /ProductAsset/{id} | Update a record of the ProductAsset
*ProductAttributeValueApi* | [**add_relation_for_product_attribute_value**](docs/ProductAttributeValueApi.md#add_relation_for_product_attribute_value) | **POST** /ProductAttributeValue/{link}/relation | Add relation for ProductAttributeValue
*ProductAttributeValueApi* | [**create_product_attribute_value_item**](docs/ProductAttributeValueApi.md#create_product_attribute_value_item) | **POST** /ProductAttributeValue | Create a record of the ProductAttributeValue
*ProductAttributeValueApi* | [**delete_product_attribute_value_item**](docs/ProductAttributeValueApi.md#delete_product_attribute_value_item) | **DELETE** /ProductAttributeValue/{id} | Delete a record of the ProductAttributeValue
*ProductAttributeValueApi* | [**follow_product_attribute_value**](docs/ProductAttributeValueApi.md#follow_product_attribute_value) | **PUT** /ProductAttributeValue/{id}/subscription | Follow the ProductAttributeValue stream
*ProductAttributeValueApi* | [**get_linked_items_for_product_attribute_value_item**](docs/ProductAttributeValueApi.md#get_linked_items_for_product_attribute_value_item) | **GET** /ProductAttributeValue/{id}/{link} | Returns linked entities for the ProductAttributeValue
*ProductAttributeValueApi* | [**get_list_of_product_attribute_value_items**](docs/ProductAttributeValueApi.md#get_list_of_product_attribute_value_items) | **GET** /ProductAttributeValue | Returns a collection of ProductAttributeValue records
*ProductAttributeValueApi* | [**get_product_attribute_value_item**](docs/ProductAttributeValueApi.md#get_product_attribute_value_item) | **GET** /ProductAttributeValue/{id} | Returns a record of the ProductAttributeValue
*ProductAttributeValueApi* | [**link_product_attribute_value**](docs/ProductAttributeValueApi.md#link_product_attribute_value) | **POST** /ProductAttributeValue/{id}/{link} | Link ProductAttributeValue to Entities
*ProductAttributeValueApi* | [**mass_delete_product_attribute_value**](docs/ProductAttributeValueApi.md#mass_delete_product_attribute_value) | **POST** /ProductAttributeValue/action/massDelete | Mass delete of ProductAttributeValue data
*ProductAttributeValueApi* | [**mass_update_product_attribute_value**](docs/ProductAttributeValueApi.md#mass_update_product_attribute_value) | **PUT** /ProductAttributeValue/action/massUpdate | Mass update of ProductAttributeValue data
*ProductAttributeValueApi* | [**remove_relation_for_product_attribute_value**](docs/ProductAttributeValueApi.md#remove_relation_for_product_attribute_value) | **DELETE** /ProductAttributeValue/{link}/relation | Remove relation for ProductAttributeValue
*ProductAttributeValueApi* | [**unfollow_product_attribute_value**](docs/ProductAttributeValueApi.md#unfollow_product_attribute_value) | **DELETE** /ProductAttributeValue/{id}/subscription | Unfollow the ProductAttributeValue stream
*ProductAttributeValueApi* | [**unlink_product_attribute_value**](docs/ProductAttributeValueApi.md#unlink_product_attribute_value) | **DELETE** /ProductAttributeValue/{id}/{link} | Unlink ProductAttributeValue from Entities
*ProductAttributeValueApi* | [**update_product_attribute_value_item**](docs/ProductAttributeValueApi.md#update_product_attribute_value_item) | **PUT** /ProductAttributeValue/{id} | Update a record of the ProductAttributeValue
*ProductChannelApi* | [**add_relation_for_product_channel**](docs/ProductChannelApi.md#add_relation_for_product_channel) | **POST** /ProductChannel/{link}/relation | Add relation for ProductChannel
*ProductChannelApi* | [**create_product_channel_item**](docs/ProductChannelApi.md#create_product_channel_item) | **POST** /ProductChannel | Create a record of the ProductChannel
*ProductChannelApi* | [**delete_product_channel_item**](docs/ProductChannelApi.md#delete_product_channel_item) | **DELETE** /ProductChannel/{id} | Delete a record of the ProductChannel
*ProductChannelApi* | [**follow_product_channel**](docs/ProductChannelApi.md#follow_product_channel) | **PUT** /ProductChannel/{id}/subscription | Follow the ProductChannel stream
*ProductChannelApi* | [**get_linked_items_for_product_channel_item**](docs/ProductChannelApi.md#get_linked_items_for_product_channel_item) | **GET** /ProductChannel/{id}/{link} | Returns linked entities for the ProductChannel
*ProductChannelApi* | [**get_list_of_product_channel_items**](docs/ProductChannelApi.md#get_list_of_product_channel_items) | **GET** /ProductChannel | Returns a collection of ProductChannel records
*ProductChannelApi* | [**get_product_channel_item**](docs/ProductChannelApi.md#get_product_channel_item) | **GET** /ProductChannel/{id} | Returns a record of the ProductChannel
*ProductChannelApi* | [**link_product_channel**](docs/ProductChannelApi.md#link_product_channel) | **POST** /ProductChannel/{id}/{link} | Link ProductChannel to Entities
*ProductChannelApi* | [**mass_delete_product_channel**](docs/ProductChannelApi.md#mass_delete_product_channel) | **POST** /ProductChannel/action/massDelete | Mass delete of ProductChannel data
*ProductChannelApi* | [**mass_update_product_channel**](docs/ProductChannelApi.md#mass_update_product_channel) | **PUT** /ProductChannel/action/massUpdate | Mass update of ProductChannel data
*ProductChannelApi* | [**remove_relation_for_product_channel**](docs/ProductChannelApi.md#remove_relation_for_product_channel) | **DELETE** /ProductChannel/{link}/relation | Remove relation for ProductChannel
*ProductChannelApi* | [**unfollow_product_channel**](docs/ProductChannelApi.md#unfollow_product_channel) | **DELETE** /ProductChannel/{id}/subscription | Unfollow the ProductChannel stream
*ProductChannelApi* | [**unlink_product_channel**](docs/ProductChannelApi.md#unlink_product_channel) | **DELETE** /ProductChannel/{id}/{link} | Unlink ProductChannel from Entities
*ProductChannelApi* | [**update_product_channel_item**](docs/ProductChannelApi.md#update_product_channel_item) | **PUT** /ProductChannel/{id} | Update a record of the ProductChannel
*ProductSerieApi* | [**add_relation_for_product_serie**](docs/ProductSerieApi.md#add_relation_for_product_serie) | **POST** /ProductSerie/{link}/relation | Add relation for ProductSerie
*ProductSerieApi* | [**create_product_serie_item**](docs/ProductSerieApi.md#create_product_serie_item) | **POST** /ProductSerie | Create a record of the ProductSerie
*ProductSerieApi* | [**delete_product_serie_item**](docs/ProductSerieApi.md#delete_product_serie_item) | **DELETE** /ProductSerie/{id} | Delete a record of the ProductSerie
*ProductSerieApi* | [**follow_product_serie**](docs/ProductSerieApi.md#follow_product_serie) | **PUT** /ProductSerie/{id}/subscription | Follow the ProductSerie stream
*ProductSerieApi* | [**get_linked_items_for_product_serie_item**](docs/ProductSerieApi.md#get_linked_items_for_product_serie_item) | **GET** /ProductSerie/{id}/{link} | Returns linked entities for the ProductSerie
*ProductSerieApi* | [**get_list_of_product_serie_items**](docs/ProductSerieApi.md#get_list_of_product_serie_items) | **GET** /ProductSerie | Returns a collection of ProductSerie records
*ProductSerieApi* | [**get_product_serie_item**](docs/ProductSerieApi.md#get_product_serie_item) | **GET** /ProductSerie/{id} | Returns a record of the ProductSerie
*ProductSerieApi* | [**link_product_serie**](docs/ProductSerieApi.md#link_product_serie) | **POST** /ProductSerie/{id}/{link} | Link ProductSerie to Entities
*ProductSerieApi* | [**mass_delete_product_serie**](docs/ProductSerieApi.md#mass_delete_product_serie) | **POST** /ProductSerie/action/massDelete | Mass delete of ProductSerie data
*ProductSerieApi* | [**mass_update_product_serie**](docs/ProductSerieApi.md#mass_update_product_serie) | **PUT** /ProductSerie/action/massUpdate | Mass update of ProductSerie data
*ProductSerieApi* | [**remove_relation_for_product_serie**](docs/ProductSerieApi.md#remove_relation_for_product_serie) | **DELETE** /ProductSerie/{link}/relation | Remove relation for ProductSerie
*ProductSerieApi* | [**unfollow_product_serie**](docs/ProductSerieApi.md#unfollow_product_serie) | **DELETE** /ProductSerie/{id}/subscription | Unfollow the ProductSerie stream
*ProductSerieApi* | [**unlink_product_serie**](docs/ProductSerieApi.md#unlink_product_serie) | **DELETE** /ProductSerie/{id}/{link} | Unlink ProductSerie from Entities
*ProductSerieApi* | [**update_product_serie_item**](docs/ProductSerieApi.md#update_product_serie_item) | **PUT** /ProductSerie/{id} | Update a record of the ProductSerie
*QueueItemApi* | [**add_relation_for_queue_item**](docs/QueueItemApi.md#add_relation_for_queue_item) | **POST** /QueueItem/{link}/relation | Add relation for QueueItem
*QueueItemApi* | [**create_queue_item_item**](docs/QueueItemApi.md#create_queue_item_item) | **POST** /QueueItem | Create a record of the QueueItem
*QueueItemApi* | [**delete_queue_item_item**](docs/QueueItemApi.md#delete_queue_item_item) | **DELETE** /QueueItem/{id} | Delete a record of the QueueItem
*QueueItemApi* | [**follow_queue_item**](docs/QueueItemApi.md#follow_queue_item) | **PUT** /QueueItem/{id}/subscription | Follow the QueueItem stream
*QueueItemApi* | [**get_linked_items_for_queue_item_item**](docs/QueueItemApi.md#get_linked_items_for_queue_item_item) | **GET** /QueueItem/{id}/{link} | Returns linked entities for the QueueItem
*QueueItemApi* | [**get_list_of_queue_item_items**](docs/QueueItemApi.md#get_list_of_queue_item_items) | **GET** /QueueItem | Returns a collection of QueueItem records
*QueueItemApi* | [**get_queue_item_item**](docs/QueueItemApi.md#get_queue_item_item) | **GET** /QueueItem/{id} | Returns a record of the QueueItem
*QueueItemApi* | [**link_queue_item**](docs/QueueItemApi.md#link_queue_item) | **POST** /QueueItem/{id}/{link} | Link QueueItem to Entities
*QueueItemApi* | [**mass_delete_queue_item**](docs/QueueItemApi.md#mass_delete_queue_item) | **POST** /QueueItem/action/massDelete | Mass delete of QueueItem data
*QueueItemApi* | [**mass_update_queue_item**](docs/QueueItemApi.md#mass_update_queue_item) | **PUT** /QueueItem/action/massUpdate | Mass update of QueueItem data
*QueueItemApi* | [**remove_relation_for_queue_item**](docs/QueueItemApi.md#remove_relation_for_queue_item) | **DELETE** /QueueItem/{link}/relation | Remove relation for QueueItem
*QueueItemApi* | [**unfollow_queue_item**](docs/QueueItemApi.md#unfollow_queue_item) | **DELETE** /QueueItem/{id}/subscription | Unfollow the QueueItem stream
*QueueItemApi* | [**unlink_queue_item**](docs/QueueItemApi.md#unlink_queue_item) | **DELETE** /QueueItem/{id}/{link} | Unlink QueueItem from Entities
*QueueItemApi* | [**update_queue_item_item**](docs/QueueItemApi.md#update_queue_item_item) | **PUT** /QueueItem/{id} | Update a record of the QueueItem
*RoleApi* | [**add_relation_for_role**](docs/RoleApi.md#add_relation_for_role) | **POST** /Role/{link}/relation | Add relation for Role
*RoleApi* | [**create_role_item**](docs/RoleApi.md#create_role_item) | **POST** /Role | Create a record of the Role
*RoleApi* | [**delete_role_item**](docs/RoleApi.md#delete_role_item) | **DELETE** /Role/{id} | Delete a record of the Role
*RoleApi* | [**follow_role**](docs/RoleApi.md#follow_role) | **PUT** /Role/{id}/subscription | Follow the Role stream
*RoleApi* | [**get_linked_items_for_role_item**](docs/RoleApi.md#get_linked_items_for_role_item) | **GET** /Role/{id}/{link} | Returns linked entities for the Role
*RoleApi* | [**get_list_of_role_items**](docs/RoleApi.md#get_list_of_role_items) | **GET** /Role | Returns a collection of Role records
*RoleApi* | [**get_role_item**](docs/RoleApi.md#get_role_item) | **GET** /Role/{id} | Returns a record of the Role
*RoleApi* | [**link_role**](docs/RoleApi.md#link_role) | **POST** /Role/{id}/{link} | Link Role to Entities
*RoleApi* | [**mass_delete_role**](docs/RoleApi.md#mass_delete_role) | **POST** /Role/action/massDelete | Mass delete of Role data
*RoleApi* | [**mass_update_role**](docs/RoleApi.md#mass_update_role) | **PUT** /Role/action/massUpdate | Mass update of Role data
*RoleApi* | [**remove_relation_for_role**](docs/RoleApi.md#remove_relation_for_role) | **DELETE** /Role/{link}/relation | Remove relation for Role
*RoleApi* | [**unfollow_role**](docs/RoleApi.md#unfollow_role) | **DELETE** /Role/{id}/subscription | Unfollow the Role stream
*RoleApi* | [**unlink_role**](docs/RoleApi.md#unlink_role) | **DELETE** /Role/{id}/{link} | Unlink Role from Entities
*RoleApi* | [**update_role_item**](docs/RoleApi.md#update_role_item) | **PUT** /Role/{id} | Update a record of the Role
*ScheduledJobApi* | [**add_relation_for_scheduled_job**](docs/ScheduledJobApi.md#add_relation_for_scheduled_job) | **POST** /ScheduledJob/{link}/relation | Add relation for ScheduledJob
*ScheduledJobApi* | [**create_scheduled_job_item**](docs/ScheduledJobApi.md#create_scheduled_job_item) | **POST** /ScheduledJob | Create a record of the ScheduledJob
*ScheduledJobApi* | [**delete_scheduled_job_item**](docs/ScheduledJobApi.md#delete_scheduled_job_item) | **DELETE** /ScheduledJob/{id} | Delete a record of the ScheduledJob
*ScheduledJobApi* | [**follow_scheduled_job**](docs/ScheduledJobApi.md#follow_scheduled_job) | **PUT** /ScheduledJob/{id}/subscription | Follow the ScheduledJob stream
*ScheduledJobApi* | [**get_linked_items_for_scheduled_job_item**](docs/ScheduledJobApi.md#get_linked_items_for_scheduled_job_item) | **GET** /ScheduledJob/{id}/{link} | Returns linked entities for the ScheduledJob
*ScheduledJobApi* | [**get_list_of_scheduled_job_items**](docs/ScheduledJobApi.md#get_list_of_scheduled_job_items) | **GET** /ScheduledJob | Returns a collection of ScheduledJob records
*ScheduledJobApi* | [**get_scheduled_job_item**](docs/ScheduledJobApi.md#get_scheduled_job_item) | **GET** /ScheduledJob/{id} | Returns a record of the ScheduledJob
*ScheduledJobApi* | [**link_scheduled_job**](docs/ScheduledJobApi.md#link_scheduled_job) | **POST** /ScheduledJob/{id}/{link} | Link ScheduledJob to Entities
*ScheduledJobApi* | [**mass_delete_scheduled_job**](docs/ScheduledJobApi.md#mass_delete_scheduled_job) | **POST** /ScheduledJob/action/massDelete | Mass delete of ScheduledJob data
*ScheduledJobApi* | [**mass_update_scheduled_job**](docs/ScheduledJobApi.md#mass_update_scheduled_job) | **PUT** /ScheduledJob/action/massUpdate | Mass update of ScheduledJob data
*ScheduledJobApi* | [**remove_relation_for_scheduled_job**](docs/ScheduledJobApi.md#remove_relation_for_scheduled_job) | **DELETE** /ScheduledJob/{link}/relation | Remove relation for ScheduledJob
*ScheduledJobApi* | [**unfollow_scheduled_job**](docs/ScheduledJobApi.md#unfollow_scheduled_job) | **DELETE** /ScheduledJob/{id}/subscription | Unfollow the ScheduledJob stream
*ScheduledJobApi* | [**unlink_scheduled_job**](docs/ScheduledJobApi.md#unlink_scheduled_job) | **DELETE** /ScheduledJob/{id}/{link} | Unlink ScheduledJob from Entities
*ScheduledJobApi* | [**update_scheduled_job_item**](docs/ScheduledJobApi.md#update_scheduled_job_item) | **PUT** /ScheduledJob/{id} | Update a record of the ScheduledJob
*ScheduledJobLogRecordApi* | [**add_relation_for_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#add_relation_for_scheduled_job_log_record) | **POST** /ScheduledJobLogRecord/{link}/relation | Add relation for ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**create_scheduled_job_log_record_item**](docs/ScheduledJobLogRecordApi.md#create_scheduled_job_log_record_item) | **POST** /ScheduledJobLogRecord | Create a record of the ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**delete_scheduled_job_log_record_item**](docs/ScheduledJobLogRecordApi.md#delete_scheduled_job_log_record_item) | **DELETE** /ScheduledJobLogRecord/{id} | Delete a record of the ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**follow_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#follow_scheduled_job_log_record) | **PUT** /ScheduledJobLogRecord/{id}/subscription | Follow the ScheduledJobLogRecord stream
*ScheduledJobLogRecordApi* | [**get_linked_items_for_scheduled_job_log_record_item**](docs/ScheduledJobLogRecordApi.md#get_linked_items_for_scheduled_job_log_record_item) | **GET** /ScheduledJobLogRecord/{id}/{link} | Returns linked entities for the ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**get_list_of_scheduled_job_log_record_items**](docs/ScheduledJobLogRecordApi.md#get_list_of_scheduled_job_log_record_items) | **GET** /ScheduledJobLogRecord | Returns a collection of ScheduledJobLogRecord records
*ScheduledJobLogRecordApi* | [**get_scheduled_job_log_record_item**](docs/ScheduledJobLogRecordApi.md#get_scheduled_job_log_record_item) | **GET** /ScheduledJobLogRecord/{id} | Returns a record of the ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**link_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#link_scheduled_job_log_record) | **POST** /ScheduledJobLogRecord/{id}/{link} | Link ScheduledJobLogRecord to Entities
*ScheduledJobLogRecordApi* | [**mass_delete_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#mass_delete_scheduled_job_log_record) | **POST** /ScheduledJobLogRecord/action/massDelete | Mass delete of ScheduledJobLogRecord data
*ScheduledJobLogRecordApi* | [**mass_update_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#mass_update_scheduled_job_log_record) | **PUT** /ScheduledJobLogRecord/action/massUpdate | Mass update of ScheduledJobLogRecord data
*ScheduledJobLogRecordApi* | [**remove_relation_for_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#remove_relation_for_scheduled_job_log_record) | **DELETE** /ScheduledJobLogRecord/{link}/relation | Remove relation for ScheduledJobLogRecord
*ScheduledJobLogRecordApi* | [**unfollow_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#unfollow_scheduled_job_log_record) | **DELETE** /ScheduledJobLogRecord/{id}/subscription | Unfollow the ScheduledJobLogRecord stream
*ScheduledJobLogRecordApi* | [**unlink_scheduled_job_log_record**](docs/ScheduledJobLogRecordApi.md#unlink_scheduled_job_log_record) | **DELETE** /ScheduledJobLogRecord/{id}/{link} | Unlink ScheduledJobLogRecord from Entities
*ScheduledJobLogRecordApi* | [**update_scheduled_job_log_record_item**](docs/ScheduledJobLogRecordApi.md#update_scheduled_job_log_record_item) | **PUT** /ScheduledJobLogRecord/{id} | Update a record of the ScheduledJobLogRecord
*SharingApi* | [**add_relation_for_sharing**](docs/SharingApi.md#add_relation_for_sharing) | **POST** /Sharing/{link}/relation | Add relation for Sharing
*SharingApi* | [**create_sharing_item**](docs/SharingApi.md#create_sharing_item) | **POST** /Sharing | Create a record of the Sharing
*SharingApi* | [**delete_sharing_item**](docs/SharingApi.md#delete_sharing_item) | **DELETE** /Sharing/{id} | Delete a record of the Sharing
*SharingApi* | [**follow_sharing**](docs/SharingApi.md#follow_sharing) | **PUT** /Sharing/{id}/subscription | Follow the Sharing stream
*SharingApi* | [**get_linked_items_for_sharing_item**](docs/SharingApi.md#get_linked_items_for_sharing_item) | **GET** /Sharing/{id}/{link} | Returns linked entities for the Sharing
*SharingApi* | [**get_list_of_sharing_items**](docs/SharingApi.md#get_list_of_sharing_items) | **GET** /Sharing | Returns a collection of Sharing records
*SharingApi* | [**get_sharing_item**](docs/SharingApi.md#get_sharing_item) | **GET** /Sharing/{id} | Returns a record of the Sharing
*SharingApi* | [**link_sharing**](docs/SharingApi.md#link_sharing) | **POST** /Sharing/{id}/{link} | Link Sharing to Entities
*SharingApi* | [**mass_delete_sharing**](docs/SharingApi.md#mass_delete_sharing) | **POST** /Sharing/action/massDelete | Mass delete of Sharing data
*SharingApi* | [**mass_update_sharing**](docs/SharingApi.md#mass_update_sharing) | **PUT** /Sharing/action/massUpdate | Mass update of Sharing data
*SharingApi* | [**remove_relation_for_sharing**](docs/SharingApi.md#remove_relation_for_sharing) | **DELETE** /Sharing/{link}/relation | Remove relation for Sharing
*SharingApi* | [**unfollow_sharing**](docs/SharingApi.md#unfollow_sharing) | **DELETE** /Sharing/{id}/subscription | Unfollow the Sharing stream
*SharingApi* | [**unlink_sharing**](docs/SharingApi.md#unlink_sharing) | **DELETE** /Sharing/{id}/{link} | Unlink Sharing from Entities
*SharingApi* | [**update_sharing_item**](docs/SharingApi.md#update_sharing_item) | **PUT** /Sharing/{id} | Update a record of the Sharing
*TaxApi* | [**add_relation_for_tax**](docs/TaxApi.md#add_relation_for_tax) | **POST** /Tax/{link}/relation | Add relation for Tax
*TaxApi* | [**create_tax_item**](docs/TaxApi.md#create_tax_item) | **POST** /Tax | Create a record of the Tax
*TaxApi* | [**delete_tax_item**](docs/TaxApi.md#delete_tax_item) | **DELETE** /Tax/{id} | Delete a record of the Tax
*TaxApi* | [**follow_tax**](docs/TaxApi.md#follow_tax) | **PUT** /Tax/{id}/subscription | Follow the Tax stream
*TaxApi* | [**get_linked_items_for_tax_item**](docs/TaxApi.md#get_linked_items_for_tax_item) | **GET** /Tax/{id}/{link} | Returns linked entities for the Tax
*TaxApi* | [**get_list_of_tax_items**](docs/TaxApi.md#get_list_of_tax_items) | **GET** /Tax | Returns a collection of Tax records
*TaxApi* | [**get_tax_item**](docs/TaxApi.md#get_tax_item) | **GET** /Tax/{id} | Returns a record of the Tax
*TaxApi* | [**link_tax**](docs/TaxApi.md#link_tax) | **POST** /Tax/{id}/{link} | Link Tax to Entities
*TaxApi* | [**mass_delete_tax**](docs/TaxApi.md#mass_delete_tax) | **POST** /Tax/action/massDelete | Mass delete of Tax data
*TaxApi* | [**mass_update_tax**](docs/TaxApi.md#mass_update_tax) | **PUT** /Tax/action/massUpdate | Mass update of Tax data
*TaxApi* | [**remove_relation_for_tax**](docs/TaxApi.md#remove_relation_for_tax) | **DELETE** /Tax/{link}/relation | Remove relation for Tax
*TaxApi* | [**unfollow_tax**](docs/TaxApi.md#unfollow_tax) | **DELETE** /Tax/{id}/subscription | Unfollow the Tax stream
*TaxApi* | [**unlink_tax**](docs/TaxApi.md#unlink_tax) | **DELETE** /Tax/{id}/{link} | Unlink Tax from Entities
*TaxApi* | [**update_tax_item**](docs/TaxApi.md#update_tax_item) | **PUT** /Tax/{id} | Update a record of the Tax
*TeamApi* | [**add_relation_for_team**](docs/TeamApi.md#add_relation_for_team) | **POST** /Team/{link}/relation | Add relation for Team
*TeamApi* | [**create_team_item**](docs/TeamApi.md#create_team_item) | **POST** /Team | Create a record of the Team
*TeamApi* | [**delete_team_item**](docs/TeamApi.md#delete_team_item) | **DELETE** /Team/{id} | Delete a record of the Team
*TeamApi* | [**follow_team**](docs/TeamApi.md#follow_team) | **PUT** /Team/{id}/subscription | Follow the Team stream
*TeamApi* | [**get_linked_items_for_team_item**](docs/TeamApi.md#get_linked_items_for_team_item) | **GET** /Team/{id}/{link} | Returns linked entities for the Team
*TeamApi* | [**get_list_of_team_items**](docs/TeamApi.md#get_list_of_team_items) | **GET** /Team | Returns a collection of Team records
*TeamApi* | [**get_team_item**](docs/TeamApi.md#get_team_item) | **GET** /Team/{id} | Returns a record of the Team
*TeamApi* | [**link_team**](docs/TeamApi.md#link_team) | **POST** /Team/{id}/{link} | Link Team to Entities
*TeamApi* | [**mass_delete_team**](docs/TeamApi.md#mass_delete_team) | **POST** /Team/action/massDelete | Mass delete of Team data
*TeamApi* | [**mass_update_team**](docs/TeamApi.md#mass_update_team) | **PUT** /Team/action/massUpdate | Mass update of Team data
*TeamApi* | [**remove_relation_for_team**](docs/TeamApi.md#remove_relation_for_team) | **DELETE** /Team/{link}/relation | Remove relation for Team
*TeamApi* | [**unfollow_team**](docs/TeamApi.md#unfollow_team) | **DELETE** /Team/{id}/subscription | Unfollow the Team stream
*TeamApi* | [**unlink_team**](docs/TeamApi.md#unlink_team) | **DELETE** /Team/{id}/{link} | Unlink Team from Entities
*TeamApi* | [**update_team_item**](docs/TeamApi.md#update_team_item) | **PUT** /Team/{id} | Update a record of the Team
*TranslationApi* | [**add_relation_for_translation**](docs/TranslationApi.md#add_relation_for_translation) | **POST** /Translation/{link}/relation | Add relation for Translation
*TranslationApi* | [**create_translation_item**](docs/TranslationApi.md#create_translation_item) | **POST** /Translation | Create a record of the Translation
*TranslationApi* | [**delete_translation_item**](docs/TranslationApi.md#delete_translation_item) | **DELETE** /Translation/{id} | Delete a record of the Translation
*TranslationApi* | [**follow_translation**](docs/TranslationApi.md#follow_translation) | **PUT** /Translation/{id}/subscription | Follow the Translation stream
*TranslationApi* | [**get_linked_items_for_translation_item**](docs/TranslationApi.md#get_linked_items_for_translation_item) | **GET** /Translation/{id}/{link} | Returns linked entities for the Translation
*TranslationApi* | [**get_list_of_translation_items**](docs/TranslationApi.md#get_list_of_translation_items) | **GET** /Translation | Returns a collection of Translation records
*TranslationApi* | [**get_translation_item**](docs/TranslationApi.md#get_translation_item) | **GET** /Translation/{id} | Returns a record of the Translation
*TranslationApi* | [**link_translation**](docs/TranslationApi.md#link_translation) | **POST** /Translation/{id}/{link} | Link Translation to Entities
*TranslationApi* | [**mass_delete_translation**](docs/TranslationApi.md#mass_delete_translation) | **POST** /Translation/action/massDelete | Mass delete of Translation data
*TranslationApi* | [**mass_update_translation**](docs/TranslationApi.md#mass_update_translation) | **PUT** /Translation/action/massUpdate | Mass update of Translation data
*TranslationApi* | [**remove_relation_for_translation**](docs/TranslationApi.md#remove_relation_for_translation) | **DELETE** /Translation/{link}/relation | Remove relation for Translation
*TranslationApi* | [**unfollow_translation**](docs/TranslationApi.md#unfollow_translation) | **DELETE** /Translation/{id}/subscription | Unfollow the Translation stream
*TranslationApi* | [**unlink_translation**](docs/TranslationApi.md#unlink_translation) | **DELETE** /Translation/{id}/{link} | Unlink Translation from Entities
*TranslationApi* | [**update_translation_item**](docs/TranslationApi.md#update_translation_item) | **PUT** /Translation/{id} | Update a record of the Translation
*TreoStoreApi* | [**add_relation_for_treo_store**](docs/TreoStoreApi.md#add_relation_for_treo_store) | **POST** /TreoStore/{link}/relation | Add relation for TreoStore
*TreoStoreApi* | [**create_treo_store_item**](docs/TreoStoreApi.md#create_treo_store_item) | **POST** /TreoStore | Create a record of the TreoStore
*TreoStoreApi* | [**delete_treo_store_item**](docs/TreoStoreApi.md#delete_treo_store_item) | **DELETE** /TreoStore/{id} | Delete a record of the TreoStore
*TreoStoreApi* | [**follow_treo_store**](docs/TreoStoreApi.md#follow_treo_store) | **PUT** /TreoStore/{id}/subscription | Follow the TreoStore stream
*TreoStoreApi* | [**get_linked_items_for_treo_store_item**](docs/TreoStoreApi.md#get_linked_items_for_treo_store_item) | **GET** /TreoStore/{id}/{link} | Returns linked entities for the TreoStore
*TreoStoreApi* | [**get_list_of_treo_store_items**](docs/TreoStoreApi.md#get_list_of_treo_store_items) | **GET** /TreoStore | Returns a collection of TreoStore records
*TreoStoreApi* | [**get_treo_store_item**](docs/TreoStoreApi.md#get_treo_store_item) | **GET** /TreoStore/{id} | Returns a record of the TreoStore
*TreoStoreApi* | [**link_treo_store**](docs/TreoStoreApi.md#link_treo_store) | **POST** /TreoStore/{id}/{link} | Link TreoStore to Entities
*TreoStoreApi* | [**mass_delete_treo_store**](docs/TreoStoreApi.md#mass_delete_treo_store) | **POST** /TreoStore/action/massDelete | Mass delete of TreoStore data
*TreoStoreApi* | [**mass_update_treo_store**](docs/TreoStoreApi.md#mass_update_treo_store) | **PUT** /TreoStore/action/massUpdate | Mass update of TreoStore data
*TreoStoreApi* | [**remove_relation_for_treo_store**](docs/TreoStoreApi.md#remove_relation_for_treo_store) | **DELETE** /TreoStore/{link}/relation | Remove relation for TreoStore
*TreoStoreApi* | [**unfollow_treo_store**](docs/TreoStoreApi.md#unfollow_treo_store) | **DELETE** /TreoStore/{id}/subscription | Unfollow the TreoStore stream
*TreoStoreApi* | [**unlink_treo_store**](docs/TreoStoreApi.md#unlink_treo_store) | **DELETE** /TreoStore/{id}/{link} | Unlink TreoStore from Entities
*TreoStoreApi* | [**update_treo_store_item**](docs/TreoStoreApi.md#update_treo_store_item) | **PUT** /TreoStore/{id} | Update a record of the TreoStore
*UnitApi* | [**add_relation_for_unit**](docs/UnitApi.md#add_relation_for_unit) | **POST** /Unit/{link}/relation | Add relation for Unit
*UnitApi* | [**create_unit_item**](docs/UnitApi.md#create_unit_item) | **POST** /Unit | Create a record of the Unit
*UnitApi* | [**delete_unit_item**](docs/UnitApi.md#delete_unit_item) | **DELETE** /Unit/{id} | Delete a record of the Unit
*UnitApi* | [**follow_unit**](docs/UnitApi.md#follow_unit) | **PUT** /Unit/{id}/subscription | Follow the Unit stream
*UnitApi* | [**get_linked_items_for_unit_item**](docs/UnitApi.md#get_linked_items_for_unit_item) | **GET** /Unit/{id}/{link} | Returns linked entities for the Unit
*UnitApi* | [**get_list_of_unit_items**](docs/UnitApi.md#get_list_of_unit_items) | **GET** /Unit | Returns a collection of Unit records
*UnitApi* | [**get_unit_item**](docs/UnitApi.md#get_unit_item) | **GET** /Unit/{id} | Returns a record of the Unit
*UnitApi* | [**link_unit**](docs/UnitApi.md#link_unit) | **POST** /Unit/{id}/{link} | Link Unit to Entities
*UnitApi* | [**mass_delete_unit**](docs/UnitApi.md#mass_delete_unit) | **POST** /Unit/action/massDelete | Mass delete of Unit data
*UnitApi* | [**mass_update_unit**](docs/UnitApi.md#mass_update_unit) | **PUT** /Unit/action/massUpdate | Mass update of Unit data
*UnitApi* | [**remove_relation_for_unit**](docs/UnitApi.md#remove_relation_for_unit) | **DELETE** /Unit/{link}/relation | Remove relation for Unit
*UnitApi* | [**unfollow_unit**](docs/UnitApi.md#unfollow_unit) | **DELETE** /Unit/{id}/subscription | Unfollow the Unit stream
*UnitApi* | [**unlink_unit**](docs/UnitApi.md#unlink_unit) | **DELETE** /Unit/{id}/{link} | Unlink Unit from Entities
*UnitApi* | [**update_unit_item**](docs/UnitApi.md#update_unit_item) | **PUT** /Unit/{id} | Update a record of the Unit
*UserApi* | [**add_relation_for_user**](docs/UserApi.md#add_relation_for_user) | **POST** /User/{link}/relation | Add relation for User
*UserApi* | [**create_user_item**](docs/UserApi.md#create_user_item) | **POST** /User | Create a record of the User
*UserApi* | [**delete_user_item**](docs/UserApi.md#delete_user_item) | **DELETE** /User/{id} | Delete a record of the User
*UserApi* | [**follow_user**](docs/UserApi.md#follow_user) | **PUT** /User/{id}/subscription | Follow the User stream
*UserApi* | [**get_linked_items_for_user_item**](docs/UserApi.md#get_linked_items_for_user_item) | **GET** /User/{id}/{link} | Returns linked entities for the User
*UserApi* | [**get_list_of_user_items**](docs/UserApi.md#get_list_of_user_items) | **GET** /User | Returns a collection of User records
*UserApi* | [**get_user_item**](docs/UserApi.md#get_user_item) | **GET** /User/{id} | Returns a record of the User
*UserApi* | [**link_user**](docs/UserApi.md#link_user) | **POST** /User/{id}/{link} | Link User to Entities
*UserApi* | [**mass_delete_user**](docs/UserApi.md#mass_delete_user) | **POST** /User/action/massDelete | Mass delete of User data
*UserApi* | [**mass_update_user**](docs/UserApi.md#mass_update_user) | **PUT** /User/action/massUpdate | Mass update of User data
*UserApi* | [**remove_relation_for_user**](docs/UserApi.md#remove_relation_for_user) | **DELETE** /User/{link}/relation | Remove relation for User
*UserApi* | [**unfollow_user**](docs/UserApi.md#unfollow_user) | **DELETE** /User/{id}/subscription | Unfollow the User stream
*UserApi* | [**unlink_user**](docs/UserApi.md#unlink_user) | **DELETE** /User/{id}/{link} | Unlink User from Entities
*UserApi* | [**update_user_item**](docs/UserApi.md#update_user_item) | **PUT** /User/{id} | Update a record of the User
*ValidationRuleApi* | [**add_relation_for_validation_rule**](docs/ValidationRuleApi.md#add_relation_for_validation_rule) | **POST** /ValidationRule/{link}/relation | Add relation for ValidationRule
*ValidationRuleApi* | [**create_validation_rule_item**](docs/ValidationRuleApi.md#create_validation_rule_item) | **POST** /ValidationRule | Create a record of the ValidationRule
*ValidationRuleApi* | [**delete_validation_rule_item**](docs/ValidationRuleApi.md#delete_validation_rule_item) | **DELETE** /ValidationRule/{id} | Delete a record of the ValidationRule
*ValidationRuleApi* | [**follow_validation_rule**](docs/ValidationRuleApi.md#follow_validation_rule) | **PUT** /ValidationRule/{id}/subscription | Follow the ValidationRule stream
*ValidationRuleApi* | [**get_linked_items_for_validation_rule_item**](docs/ValidationRuleApi.md#get_linked_items_for_validation_rule_item) | **GET** /ValidationRule/{id}/{link} | Returns linked entities for the ValidationRule
*ValidationRuleApi* | [**get_list_of_validation_rule_items**](docs/ValidationRuleApi.md#get_list_of_validation_rule_items) | **GET** /ValidationRule | Returns a collection of ValidationRule records
*ValidationRuleApi* | [**get_validation_rule_item**](docs/ValidationRuleApi.md#get_validation_rule_item) | **GET** /ValidationRule/{id} | Returns a record of the ValidationRule
*ValidationRuleApi* | [**link_validation_rule**](docs/ValidationRuleApi.md#link_validation_rule) | **POST** /ValidationRule/{id}/{link} | Link ValidationRule to Entities
*ValidationRuleApi* | [**mass_delete_validation_rule**](docs/ValidationRuleApi.md#mass_delete_validation_rule) | **POST** /ValidationRule/action/massDelete | Mass delete of ValidationRule data
*ValidationRuleApi* | [**mass_update_validation_rule**](docs/ValidationRuleApi.md#mass_update_validation_rule) | **PUT** /ValidationRule/action/massUpdate | Mass update of ValidationRule data
*ValidationRuleApi* | [**remove_relation_for_validation_rule**](docs/ValidationRuleApi.md#remove_relation_for_validation_rule) | **DELETE** /ValidationRule/{link}/relation | Remove relation for ValidationRule
*ValidationRuleApi* | [**unfollow_validation_rule**](docs/ValidationRuleApi.md#unfollow_validation_rule) | **DELETE** /ValidationRule/{id}/subscription | Unfollow the ValidationRule stream
*ValidationRuleApi* | [**unlink_validation_rule**](docs/ValidationRuleApi.md#unlink_validation_rule) | **DELETE** /ValidationRule/{id}/{link} | Unlink ValidationRule from Entities
*ValidationRuleApi* | [**update_validation_rule_item**](docs/ValidationRuleApi.md#update_validation_rule_item) | **PUT** /ValidationRule/{id} | Update a record of the ValidationRule
*VariableApi* | [**add_relation_for_variable**](docs/VariableApi.md#add_relation_for_variable) | **POST** /Variable/{link}/relation | Add relation for Variable
*VariableApi* | [**create_variable_item**](docs/VariableApi.md#create_variable_item) | **POST** /Variable | Create a record of the Variable
*VariableApi* | [**delete_variable_item**](docs/VariableApi.md#delete_variable_item) | **DELETE** /Variable/{id} | Delete a record of the Variable
*VariableApi* | [**follow_variable**](docs/VariableApi.md#follow_variable) | **PUT** /Variable/{id}/subscription | Follow the Variable stream
*VariableApi* | [**get_linked_items_for_variable_item**](docs/VariableApi.md#get_linked_items_for_variable_item) | **GET** /Variable/{id}/{link} | Returns linked entities for the Variable
*VariableApi* | [**get_list_of_variable_items**](docs/VariableApi.md#get_list_of_variable_items) | **GET** /Variable | Returns a collection of Variable records
*VariableApi* | [**get_variable_item**](docs/VariableApi.md#get_variable_item) | **GET** /Variable/{id} | Returns a record of the Variable
*VariableApi* | [**link_variable**](docs/VariableApi.md#link_variable) | **POST** /Variable/{id}/{link} | Link Variable to Entities
*VariableApi* | [**mass_delete_variable**](docs/VariableApi.md#mass_delete_variable) | **POST** /Variable/action/massDelete | Mass delete of Variable data
*VariableApi* | [**mass_update_variable**](docs/VariableApi.md#mass_update_variable) | **PUT** /Variable/action/massUpdate | Mass update of Variable data
*VariableApi* | [**remove_relation_for_variable**](docs/VariableApi.md#remove_relation_for_variable) | **DELETE** /Variable/{link}/relation | Remove relation for Variable
*VariableApi* | [**unfollow_variable**](docs/VariableApi.md#unfollow_variable) | **DELETE** /Variable/{id}/subscription | Unfollow the Variable stream
*VariableApi* | [**unlink_variable**](docs/VariableApi.md#unlink_variable) | **DELETE** /Variable/{id}/{link} | Unlink Variable from Entities
*VariableApi* | [**update_variable_item**](docs/VariableApi.md#update_variable_item) | **PUT** /Variable/{id} | Update a record of the Variable


## Documentation For Models

 - [Account](docs/Account.md)
 - [ActionHistoryRecord](docs/ActionHistoryRecord.md)
 - [Asset](docs/Asset.md)
 - [AssetCategory](docs/AssetCategory.md)
 - [AssetMetadata](docs/AssetMetadata.md)
 - [AssetType](docs/AssetType.md)
 - [AssociatedProduct](docs/AssociatedProduct.md)
 - [Association](docs/Association.md)
 - [Attachment](docs/Attachment.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeGroup](docs/AttributeGroup.md)
 - [AttributeTab](docs/AttributeTab.md)
 - [AuthLogRecord](docs/AuthLogRecord.md)
 - [AuthToken](docs/AuthToken.md)
 - [Brand](docs/Brand.md)
 - [Call](docs/Call.md)
 - [Catalog](docs/Catalog.md)
 - [Category](docs/Category.md)
 - [CategoryAsset](docs/CategoryAsset.md)
 - [Channel](docs/Channel.md)
 - [Classification](docs/Classification.md)
 - [ClassificationAttribute](docs/ClassificationAttribute.md)
 - [Connection](docs/Connection.md)
 - [Content](docs/Content.md)
 - [ContentGroup](docs/ContentGroup.md)
 - [CreateAccountItemRequest](docs/CreateAccountItemRequest.md)
 - [CreateAssetCategoryItemRequest](docs/CreateAssetCategoryItemRequest.md)
 - [CreateAssetItemRequest](docs/CreateAssetItemRequest.md)
 - [CreateAssetMetadataItemRequest](docs/CreateAssetMetadataItemRequest.md)
 - [CreateAssetTypeItemRequest](docs/CreateAssetTypeItemRequest.md)
 - [CreateAssociatedProductItemRequest](docs/CreateAssociatedProductItemRequest.md)
 - [CreateAssociationItemRequest](docs/CreateAssociationItemRequest.md)
 - [CreateAttachmentItemRequest](docs/CreateAttachmentItemRequest.md)
 - [CreateAttributeGroupItemRequest](docs/CreateAttributeGroupItemRequest.md)
 - [CreateAttributeItemRequest](docs/CreateAttributeItemRequest.md)
 - [CreateAttributeTabItemRequest](docs/CreateAttributeTabItemRequest.md)
 - [CreateAuthLogRecordItemRequest](docs/CreateAuthLogRecordItemRequest.md)
 - [CreateAuthTokenItemRequest](docs/CreateAuthTokenItemRequest.md)
 - [CreateBrandItemRequest](docs/CreateBrandItemRequest.md)
 - [CreateCatalogItemRequest](docs/CreateCatalogItemRequest.md)
 - [CreateCategoryAssetItemRequest](docs/CreateCategoryAssetItemRequest.md)
 - [CreateCategoryItemRequest](docs/CreateCategoryItemRequest.md)
 - [CreateChannelItemRequest](docs/CreateChannelItemRequest.md)
 - [CreateClassificationAttributeItemRequest](docs/CreateClassificationAttributeItemRequest.md)
 - [CreateClassificationItemRequest](docs/CreateClassificationItemRequest.md)
 - [CreateConnectionItemRequest](docs/CreateConnectionItemRequest.md)
 - [CreateContentGroupItemRequest](docs/CreateContentGroupItemRequest.md)
 - [CreateContentItemRequest](docs/CreateContentItemRequest.md)
 - [CreateExportConfiguratorItemItemRequest](docs/CreateExportConfiguratorItemItemRequest.md)
 - [CreateExportFeedItemRequest](docs/CreateExportFeedItemRequest.md)
 - [CreateExportJobItemRequest](docs/CreateExportJobItemRequest.md)
 - [CreateExtensibleEnumItemRequest](docs/CreateExtensibleEnumItemRequest.md)
 - [CreateExtensibleEnumOptionItemRequest](docs/CreateExtensibleEnumOptionItemRequest.md)
 - [CreateImportConfiguratorItemItemRequest](docs/CreateImportConfiguratorItemItemRequest.md)
 - [CreateImportFeedItemRequest](docs/CreateImportFeedItemRequest.md)
 - [CreateImportJobItemRequest](docs/CreateImportJobItemRequest.md)
 - [CreateImportJobLogItemRequest](docs/CreateImportJobLogItemRequest.md)
 - [CreateJobItemRequest](docs/CreateJobItemRequest.md)
 - [CreateLibraryItemRequest](docs/CreateLibraryItemRequest.md)
 - [CreateLocaleItemRequest](docs/CreateLocaleItemRequest.md)
 - [CreateMeasureItemRequest](docs/CreateMeasureItemRequest.md)
 - [CreateNoteItemRequest](docs/CreateNoteItemRequest.md)
 - [CreateNotificationItemRequest](docs/CreateNotificationItemRequest.md)
 - [CreatePackagingItemRequest](docs/CreatePackagingItemRequest.md)
 - [CreatePortalItemRequest](docs/CreatePortalItemRequest.md)
 - [CreatePreferencesItemRequest](docs/CreatePreferencesItemRequest.md)
 - [CreateProductAssetItemRequest](docs/CreateProductAssetItemRequest.md)
 - [CreateProductAttributeValueItemRequest](docs/CreateProductAttributeValueItemRequest.md)
 - [CreateProductChannelItemRequest](docs/CreateProductChannelItemRequest.md)
 - [CreateProductItemRequest](docs/CreateProductItemRequest.md)
 - [CreateProductSerieItemRequest](docs/CreateProductSerieItemRequest.md)
 - [CreateQueueItemItemRequest](docs/CreateQueueItemItemRequest.md)
 - [CreateRoleItemRequest](docs/CreateRoleItemRequest.md)
 - [CreateScheduledJobItemRequest](docs/CreateScheduledJobItemRequest.md)
 - [CreateScheduledJobLogRecordItemRequest](docs/CreateScheduledJobLogRecordItemRequest.md)
 - [CreateSharingItemRequest](docs/CreateSharingItemRequest.md)
 - [CreateTaxItemRequest](docs/CreateTaxItemRequest.md)
 - [CreateTeamItemRequest](docs/CreateTeamItemRequest.md)
 - [CreateTranslationItemRequest](docs/CreateTranslationItemRequest.md)
 - [CreateTreoStoreItemRequest](docs/CreateTreoStoreItemRequest.md)
 - [CreateUnitItemRequest](docs/CreateUnitItemRequest.md)
 - [CreateUserItemRequest](docs/CreateUserItemRequest.md)
 - [CreateValidationRuleItemRequest](docs/CreateValidationRuleItemRequest.md)
 - [CreateVariableItemRequest](docs/CreateVariableItemRequest.md)
 - [Currency](docs/Currency.md)
 - [ExportConfiguratorItem](docs/ExportConfiguratorItem.md)
 - [ExportFeed](docs/ExportFeed.md)
 - [ExportJob](docs/ExportJob.md)
 - [ExtensibleEnum](docs/ExtensibleEnum.md)
 - [ExtensibleEnumOption](docs/ExtensibleEnumOption.md)
 - [FollowAccount200Response](docs/FollowAccount200Response.md)
 - [GetAuthorizedUserData200Response](docs/GetAuthorizedUserData200Response.md)
 - [GetInstalledModules200Response](docs/GetInstalledModules200Response.md)
 - [GetInstalledModules200ResponseListInner](docs/GetInstalledModules200ResponseListInner.md)
 - [GetLinkedItemsForAccountItem200Response](docs/GetLinkedItemsForAccountItem200Response.md)
 - [GetListOfAccountItems200Response](docs/GetListOfAccountItems200Response.md)
 - [GetListOfAssetCategoryItems200Response](docs/GetListOfAssetCategoryItems200Response.md)
 - [GetListOfAssetItems200Response](docs/GetListOfAssetItems200Response.md)
 - [GetListOfAssetMetadataItems200Response](docs/GetListOfAssetMetadataItems200Response.md)
 - [GetListOfAssetTypeItems200Response](docs/GetListOfAssetTypeItems200Response.md)
 - [GetListOfAssociatedProductItems200Response](docs/GetListOfAssociatedProductItems200Response.md)
 - [GetListOfAssociationItems200Response](docs/GetListOfAssociationItems200Response.md)
 - [GetListOfAttachmentItems200Response](docs/GetListOfAttachmentItems200Response.md)
 - [GetListOfAttributeGroupItems200Response](docs/GetListOfAttributeGroupItems200Response.md)
 - [GetListOfAttributeItems200Response](docs/GetListOfAttributeItems200Response.md)
 - [GetListOfAttributeTabItems200Response](docs/GetListOfAttributeTabItems200Response.md)
 - [GetListOfAuthLogRecordItems200Response](docs/GetListOfAuthLogRecordItems200Response.md)
 - [GetListOfAuthTokenItems200Response](docs/GetListOfAuthTokenItems200Response.md)
 - [GetListOfBrandItems200Response](docs/GetListOfBrandItems200Response.md)
 - [GetListOfCatalogItems200Response](docs/GetListOfCatalogItems200Response.md)
 - [GetListOfCategoryAssetItems200Response](docs/GetListOfCategoryAssetItems200Response.md)
 - [GetListOfCategoryItems200Response](docs/GetListOfCategoryItems200Response.md)
 - [GetListOfChannelItems200Response](docs/GetListOfChannelItems200Response.md)
 - [GetListOfClassificationAttributeItems200Response](docs/GetListOfClassificationAttributeItems200Response.md)
 - [GetListOfClassificationItems200Response](docs/GetListOfClassificationItems200Response.md)
 - [GetListOfConnectionItems200Response](docs/GetListOfConnectionItems200Response.md)
 - [GetListOfContentGroupItems200Response](docs/GetListOfContentGroupItems200Response.md)
 - [GetListOfContentItems200Response](docs/GetListOfContentItems200Response.md)
 - [GetListOfExportConfiguratorItemItems200Response](docs/GetListOfExportConfiguratorItemItems200Response.md)
 - [GetListOfExportFeedItems200Response](docs/GetListOfExportFeedItems200Response.md)
 - [GetListOfExportJobItems200Response](docs/GetListOfExportJobItems200Response.md)
 - [GetListOfExtensibleEnumItems200Response](docs/GetListOfExtensibleEnumItems200Response.md)
 - [GetListOfExtensibleEnumOptionItems200Response](docs/GetListOfExtensibleEnumOptionItems200Response.md)
 - [GetListOfImportConfiguratorItemItems200Response](docs/GetListOfImportConfiguratorItemItems200Response.md)
 - [GetListOfImportFeedItems200Response](docs/GetListOfImportFeedItems200Response.md)
 - [GetListOfImportJobItems200Response](docs/GetListOfImportJobItems200Response.md)
 - [GetListOfImportJobLogItems200Response](docs/GetListOfImportJobLogItems200Response.md)
 - [GetListOfJobItems200Response](docs/GetListOfJobItems200Response.md)
 - [GetListOfLibraryItems200Response](docs/GetListOfLibraryItems200Response.md)
 - [GetListOfLocaleItems200Response](docs/GetListOfLocaleItems200Response.md)
 - [GetListOfMeasureItems200Response](docs/GetListOfMeasureItems200Response.md)
 - [GetListOfNoteItems200Response](docs/GetListOfNoteItems200Response.md)
 - [GetListOfNotificationItems200Response](docs/GetListOfNotificationItems200Response.md)
 - [GetListOfPackagingItems200Response](docs/GetListOfPackagingItems200Response.md)
 - [GetListOfPortalItems200Response](docs/GetListOfPortalItems200Response.md)
 - [GetListOfPreferencesItems200Response](docs/GetListOfPreferencesItems200Response.md)
 - [GetListOfProductAssetItems200Response](docs/GetListOfProductAssetItems200Response.md)
 - [GetListOfProductAttributeValueItems200Response](docs/GetListOfProductAttributeValueItems200Response.md)
 - [GetListOfProductChannelItems200Response](docs/GetListOfProductChannelItems200Response.md)
 - [GetListOfProductItems200Response](docs/GetListOfProductItems200Response.md)
 - [GetListOfProductSerieItems200Response](docs/GetListOfProductSerieItems200Response.md)
 - [GetListOfQueueItemItems200Response](docs/GetListOfQueueItemItems200Response.md)
 - [GetListOfRoleItems200Response](docs/GetListOfRoleItems200Response.md)
 - [GetListOfScheduledJobItems200Response](docs/GetListOfScheduledJobItems200Response.md)
 - [GetListOfScheduledJobLogRecordItems200Response](docs/GetListOfScheduledJobLogRecordItems200Response.md)
 - [GetListOfSharingItems200Response](docs/GetListOfSharingItems200Response.md)
 - [GetListOfTaxItems200Response](docs/GetListOfTaxItems200Response.md)
 - [GetListOfTeamItems200Response](docs/GetListOfTeamItems200Response.md)
 - [GetListOfTranslationItems200Response](docs/GetListOfTranslationItems200Response.md)
 - [GetListOfTreoStoreItems200Response](docs/GetListOfTreoStoreItems200Response.md)
 - [GetListOfUnitItems200Response](docs/GetListOfUnitItems200Response.md)
 - [GetListOfUserItems200Response](docs/GetListOfUserItems200Response.md)
 - [GetListOfValidationRuleItems200Response](docs/GetListOfValidationRuleItems200Response.md)
 - [GetListOfVariableItems200Response](docs/GetListOfVariableItems200Response.md)
 - [GetModulesLogs200Response](docs/GetModulesLogs200Response.md)
 - [GetModulesLogs200ResponseListInner](docs/GetModulesLogs200ResponseListInner.md)
 - [ImportConfiguratorItem](docs/ImportConfiguratorItem.md)
 - [ImportFeed](docs/ImportFeed.md)
 - [ImportJob](docs/ImportJob.md)
 - [ImportJobLog](docs/ImportJobLog.md)
 - [InstallModuleRequest](docs/InstallModuleRequest.md)
 - [Job](docs/Job.md)
 - [Library](docs/Library.md)
 - [LinkAccountRequest](docs/LinkAccountRequest.md)
 - [Locale](docs/Locale.md)
 - [MassUpdateAccountRequest](docs/MassUpdateAccountRequest.md)
 - [Measure](docs/Measure.md)
 - [NextNumber](docs/NextNumber.md)
 - [Note](docs/Note.md)
 - [Notification](docs/Notification.md)
 - [Packaging](docs/Packaging.md)
 - [PasswordChangeRequest](docs/PasswordChangeRequest.md)
 - [Portal](docs/Portal.md)
 - [PortalRole](docs/PortalRole.md)
 - [Preferences](docs/Preferences.md)
 - [Product](docs/Product.md)
 - [ProductAsset](docs/ProductAsset.md)
 - [ProductAttributeValue](docs/ProductAttributeValue.md)
 - [ProductChannel](docs/ProductChannel.md)
 - [ProductSerie](docs/ProductSerie.md)
 - [PseudoTransactionJob](docs/PseudoTransactionJob.md)
 - [QueueItem](docs/QueueItem.md)
 - [Role](docs/Role.md)
 - [RunImportRequest](docs/RunImportRequest.md)
 - [ScheduledJob](docs/ScheduledJob.md)
 - [ScheduledJobLogRecord](docs/ScheduledJobLogRecord.md)
 - [Settings](docs/Settings.md)
 - [Sharing](docs/Sharing.md)
 - [Tax](docs/Tax.md)
 - [Team](docs/Team.md)
 - [Translation](docs/Translation.md)
 - [TreoStore](docs/TreoStore.md)
 - [Unit](docs/Unit.md)
 - [User](docs/User.md)
 - [ValidationRule](docs/ValidationRule.md)
 - [Variable](docs/Variable.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="Authorization-Token"></a>
### Authorization-Token

- **Type**: API key
- **API key parameter name**: Authorization-Token
- **Location**: HTTP header


## Author




